class TileNPCData:
    # const
    TileID_Count: int = 753
    ProjectileID_Count: int = 1111
    BuffID_Count: int = 389
    NPCID_Count: int = 697
    WallID_Count: int = 367

    # npc
    slimeRainNPC: list[bool] = []
    npcCatchable: list[bool] = []

    # pet
    projPet: list[bool] = []
    vanityPet: list[bool] = []
    lightPet: list[bool] = []

    # tiles
    tileDungeon: list[bool] = []
    tileStone: list[bool] = []
    tileSand: list[bool] = []
    tileAxe: list[bool] = []
    tileHammer: list[bool] = []
    tileCracked: list[bool] = []
    tileMoss: list[bool] = []
    tileOreFinderPriority: list[int] = []
    tileLighted: list[bool] = []
    tileFlame: list[bool] = []
    tileRope: list[bool] = []
    tilePile: list[bool] = []
    tileSpelunker: list[bool] = []
    tileSolid: list[bool] = []
    tileMergeDirt: list[bool] = []
    tileBrick: list[bool] = []
    tileLavaDeath: list[bool] = []
    tileWaterDeath: list[bool] = []
    tileBlockLight: list[bool] = []
    tileBouncy: list[bool] = []
    tileFrameImportant: list[bool] = []
    tileNoFail: list[bool] = []
    tileLargeFrames: list[int] = []
    tileBlendAll: list[bool] = []
    tileGlowMask: list[int] = []
    tileShine: list[int] = []
    tileShine2: list[bool] = []
    tileCut: list[bool] = []
    tileAlch: list[bool] = []
    tileNoAttach: list[bool] = []
    tileNoSunLight: list[bool] = []
    tileObsidianKill: list[bool] = []
    tileSolidTop: list[bool] = []
    tileTable: list[bool] = []
    tileFrame: list[int] = []
    tileFrameCounter: list[int] = []
    tileContainer: list[bool] = []
    tileSign: list[bool] = []

    # other
    projFrames: list[int] = []
    wallHouse: list[bool] = []
    wallLight: list[bool] = []
    wallDungeon: list[bool] = []
    wallLargeFrames: list[int] = []

    # buffs
    debuff: list[bool] = []
    pvpBuff: list[bool] = []
    meleeBuff: list[bool] = []
    buffNoSave: list[bool] = []
    buffNoTimeDisplay: list[bool] = []
    persistentBuff: list[bool] = []

    # Initialize all
    def __init__(self):
        tc = self.TileID_Count
        # pc = self.ProjectileID_Count
        nc = self.NPCID_Count
        bc = self.BuffID_Count
        wc = self.WallID_Count
        # tile lists
        self.tileDungeon = [False] * tc
        self.tileStone = [False] * tc
        self.tileSand = [False] * tc
        self.tileAxe = [False] * tc
        self.tileHammer = [False] * tc
        self.tileCracked = [False] * tc
        self.tileMoss = [False] * tc
        self.tileOreFinderPriority = [-1] * tc
        self.tileLighted = [False] * tc
        self.tileFlame = [False] * tc
        self.tileRope = [False] * tc
        self.tilePile = [False] * tc
        self.tileSpelunker = [False] * tc
        self.tileSolid = [False] * tc
        self.tileMergeDirt = [False] * tc
        self.tileBrick = [False] * tc
        self.tileLavaDeath = [False] * tc
        self.tileWaterDeath = [False] * tc
        self.tileBlockLight = [False] * tc
        self.tileBouncy = [False] * tc
        self.tileFrameImportant = [False] * tc
        self.tileNoFail = [False] * tc
        self.tileLargeFrames = [0] * tc
        self.tileBlendAll = [False] * tc
        self.tileShine = [0] * tc
        self.tileShine2 = [False] * tc
        self.tileCut = [False] * tc
        self.tileAlch = [False] * tc
        self.tileNoAttach = [False] * tc
        self.tileNoSunLight = [False] * tc
        self.tileObsidianKill = [False] * tc
        self.tileSolidTop = [False] * tc
        self.tileTable = [False] * tc
        self.tileFrame = [0] * tc
        self.tileFrameCounter = [0] * tc
        self.tileContainer = [False] * tc
        self.tileSign = [False] * tc
        # npc
        self.slimeRainNPC = [False] * nc
        self.npcCatchable = [False] * nc
        # wall
        self.wallHouse = [False] * wc
        self.wallLight = [False] * wc
        self.wallDungeon = [False] * wc
        self.wallLargeFrames = [0] * wc
        # buff
        self.debuff = [False] * bc
        self.pvpBuff = [False] * bc
        self.meleeBuff = [False] * bc
        self.buffNoSave = [False] * bc
        self.buffNoTimeDisplay = [False] * bc
        self.persistentBuff = [False] * bc
        self.init_tile_and_npc_data1()
        self.init_tile_and_npc_data2()

    # Initialize_TileAndNPCData1
    def init_tile_and_npc_data1(self) -> None:
        self.tileGlowMask = [-1] * self.TileID_Count
        self.projFrames = [1] * self.ProjectileID_Count
        self.projFrames[1078] = 3
        self.projFrames[1024] = 8
        self.projFrames[736] = 3
        self.projFrames[737] = 3
        self.projFrames[738] = 3
        self.projFrames[779] = 4
        self.projFrames[783] = 4
        self.projFrames[862] = 4
        self.projFrames[863] = 4
        self.projFrames[820] = 4
        self.projFrames[916] = 6
        self.projFrames[34] = 6
        self.projFrames[1088] = 2
        self.projFrames[706] = 8
        self.projFrames[712] = 8
        self.projFrames[663] = 7
        self.projFrames[665] = 9
        self.projFrames[667] = 9
        self.projFrames[677] = 6
        self.projFrames[678] = 6
        self.projFrames[679] = 6
        self.projFrames[688] = 6
        self.projFrames[689] = 6
        self.projFrames[690] = 8
        self.projFrames[691] = 4
        self.projFrames[692] = 4
        self.projFrames[693] = 4
        self.projFrames[694] = 4
        self.projFrames[695] = 4
        self.projFrames[696] = 5
        self.projFrames[700] = 4
        self.projFrames[964] = 1
        self.projFrames[965] = 1
        self.projFrames[643] = 8
        self.projFrames[566] = 4
        self.projFrames[565] = 4
        self.projFrames[525] = 5
        self.projFrames[519] = 4
        self.projFrames[509] = 2
        self.projFrames[485] = 5
        self.projFrames[492] = 8
        self.projFrames[500] = 4
        self.projFrames[499] = 12
        self.projFrames[518] = 4
        self.projFrames[585] = 4
        self.projFrames[593] = 4
        self.projFrames[595] = 28
        self.projFrames[735] = 28
        self.projFrames[596] = 4
        self.projFrames[612] = 5
        self.projFrames[978] = 5
        self.projFrames[613] = 4
        self.projFrames[614] = 4
        self.projFrames[615] = 7
        self.projFrames[623] = 19
        self.projFrames[633] = 5
        self.projFrames[645] = 7
        self.projFrames[650] = 4
        self.projFrames[652] = 6
        self.projFrames[659] = 4
        self.projFrames[714] = 7
        self.projFrames[734] = 8
        self.projFrames[755] = 5
        self.projFrames[759] = 5
        self.projFrames[765] = 10
        self.projFrames[951] = 12
        self.projFrames[953] = 5
        self.projFrames[1022] = 16
        self.projFrames[1036] = 4
        self.projFrames[384] = 6
        self.projFrames[385] = 3
        self.projFrames[386] = 6
        self.projFrames[390] = 11
        self.projFrames[391] = 11
        self.projFrames[392] = 11
        self.projFrames[393] = 15
        self.projFrames[394] = 15
        self.projFrames[395] = 15
        self.projFrames[398] = 11
        self.projFrames[407] = 6
        self.projFrames[408] = 2
        self.projFrames[409] = 3
        self.projFrames[387] = 3
        self.projFrames[388] = 3
        self.projFrames[334] = 11
        self.projFrames[324] = 10
        self.projFrames[351] = 2
        self.projFrames[349] = 5
        self.projFrames[423] = 4
        self.projFrames[435] = 4
        self.projFrames[682] = 4
        self.projFrames[436] = 4
        self.projFrames[439] = 6
        self.projFrames[443] = 4
        self.projFrames[447] = 4
        self.projFrames[448] = 3
        self.projFrames[450] = 5
        self.projFrames[454] = 2
        self.projFrames[456] = 4
        self.projFrames[459] = 3
        self.projFrames[462] = 5
        self.projFrames[465] = 4
        self.projFrames[467] = 4
        self.projFrames[468] = 4
        self.projFrames[533] = 21
        self.projFrames[535] = 12
        self.projFrames[539] = 4
        self.projFrames[575] = 4
        self.projFrames[574] = 2
        self.projFrames[634] = 4
        self.projFrames[635] = 4
        self.projFrames[709] = 3
        self.projFrames[1038] = 8
        self.projFrames[1093] = 28
        self.projFrames[1110] = 4
        self.projFrames[353] = 14
        self.projFrames[346] = 2
        self.projFrames[347] = 2
        self.projFrames[335] = 4
        self.projFrames[344] = 3
        self.projFrames[337] = 5
        self.projFrames[317] = 8
        self.projFrames[321] = 3
        self.projFrames[308] = 10
        self.projFrames[316] = 4
        self.projFrames[275] = 2
        self.projFrames[276] = 2
        self.projFrames[254] = 5
        self.projFrames[307] = 2
        self.projFrames[72] = 4
        self.projFrames[86] = 4
        self.projFrames[87] = 4
        self.projFrames[102] = 2
        self.projFrames[111] = 8
        self.projFrames[112] = 6
        self.projFrames[127] = 16
        self.projFrames[175] = 2
        self.projFrames[181] = 4
        self.projFrames[189] = 4
        self.projFrames[191] = 18
        self.projFrames[192] = 18
        self.projFrames[193] = 18
        self.projFrames[194] = 18
        self.projFrames[190] = 4
        self.projFrames[198] = 4
        self.projFrames[199] = 8
        self.projFrames[200] = 10
        self.projFrames[206] = 5
        self.projFrames[208] = 5
        self.projFrames[209] = 12
        self.projFrames[210] = 12
        self.projFrames[211] = 10
        self.projFrames[221] = 3
        self.projFrames[237] = 4
        self.projFrames[238] = 6
        self.projFrames[221] = 3
        self.projFrames[228] = 5
        self.projFrames[229] = 4
        self.projFrames[236] = 13
        self.projFrames[243] = 4
        self.projFrames[244] = 6
        self.projFrames[249] = 5
        self.projFrames[252] = 4
        self.projFrames[266] = 12
        self.projFrames[268] = 8
        self.projFrames[269] = 7
        self.projFrames[270] = 3
        self.projFrames[313] = 12
        self.projFrames[314] = 13
        self.projFrames[319] = 11
        self.projFrames[373] = 3
        self.projFrames[375] = 8
        self.projFrames[377] = 9
        self.projFrames[379] = 4
        self.projFrames[380] = 4
        self.projFrames[601] = 2
        self.projFrames[602] = 4
        self.projFrames[703] = 8
        self.projFrames[701] = 3
        self.projFrames[702] = 4
        self.projFrames[732] = 4
        self.projFrames[731] = 4
        self.projFrames[758] = 24
        self.projFrames[766] = 4
        self.projFrames[767] = 4
        self.projFrames[768] = 4
        self.projFrames[769] = 4
        self.projFrames[770] = 4
        self.projFrames[774] = 8
        self.projFrames[773] = 4
        self.projFrames[815] = 10
        self.projFrames[816] = 17
        self.projFrames[817] = 18
        self.projFrames[821] = 23
        self.projFrames[824] = 4
        self.projFrames[825] = 26
        self.projFrames[826] = 3
        self.projFrames[828] = 2
        self.projFrames[829] = 2
        self.projFrames[831] = 6
        self.projFrames[970] = 6
        self.projFrames[833] = 10
        self.projFrames[834] = 12
        self.projFrames[835] = 12
        self.projFrames[836] = 4
        self.projFrames[837] = 3
        self.projFrames[839] = 4
        self.projFrames[840] = 4
        self.projFrames[851] = 4
        self.projFrames[853] = 4
        self.projFrames[854] = 19
        self.projFrames[855] = 4
        self.projFrames[858] = 14
        self.projFrames[859] = 24
        self.projFrames[860] = 14
        self.projFrames[861] = 4
        self.projFrames[864] = 2
        self.projFrames[866] = 4
        self.projFrames[870] = 4
        self.projFrames[875] = 11
        self.projFrames[881] = 12
        self.projFrames[882] = 20
        self.projFrames[883] = 3
        self.projFrames[884] = 14
        self.projFrames[885] = 10
        self.projFrames[886] = 8
        self.projFrames[887] = 3
        self.projFrames[888] = 36
        self.projFrames[889] = 11
        self.projFrames[890] = 12
        self.projFrames[891] = 15
        self.projFrames[892] = 6
        self.projFrames[893] = 4
        self.projFrames[894] = 8
        self.projFrames[895] = 6
        self.projFrames[896] = 16
        self.projFrames[897] = 11
        self.projFrames[898] = 16
        self.projFrames[899] = 14
        self.projFrames[900] = 14
        self.projFrames[901] = 12
        self.projFrames[908] = 12
        self.projFrames[909] = 6
        self.projFrames[920] = 3
        self.projFrames[934] = 12
        self.projFrames[880] = 8
        self.projFrames[929] = 8
        self.projFrames[956] = 11
        self.projFrames[957] = 12
        self.projFrames[958] = 17
        self.projFrames[959] = 12
        self.projFrames[960] = 20
        self.projFrames[961] = 1
        self.projFrames[962] = 3
        self.projFrames[963] = 13
        self.projFrames[966] = 3
        self.projFrames[967] = 8
        self.projFrames[968] = 24
        self.projFrames[969] = 8
        self.projFrames[994] = 16
        self.projFrames[995] = 20
        self.projFrames[998] = 10
        self.projFrames[1003] = 16
        self.projFrames[1004] = 15
        self.projFrames[1014] = 11
        self.projFrames[1055] = 10
        self.projFrames[1025] = 4
        self.projFrames[1026] = 4
        self.projFrames[1027] = 5
        self.projFrames[1046] = 12
        self.projFrames[1050] = 16
        self.projFrames[1092] = 54
        self.projFrames[1095] = 12
        self.projFrames[1096] = 12
        self.projFrames[1098] = 11
        self.projFrames[1105] = 7
        self.projPet = [False] * self.ProjectileID_Count
        self.vanityPet = [False] * self.ProjectileID_Count
        self.lightPet = [False] * self.ProjectileID_Count
        self.projPet[492] = True
        self.projPet[499] = True
        self.projPet[653] = True
        self.projPet[701] = True
        self.projPet[703] = True
        self.projPet[702] = True
        self.projPet[764] = True
        self.projPet[765] = True
        self.projPet[319] = True
        self.projPet[334] = True
        self.projPet[324] = True
        self.projPet[266] = True
        self.projPet[313] = True
        self.projPet[314] = True
        self.projPet[317] = True
        self.projPet[175] = True
        self.projPet[111] = True
        self.projPet[112] = True
        self.projPet[127] = True
        self.projPet[191] = True
        self.projPet[192] = True
        self.projPet[193] = True
        self.projPet[194] = True
        self.projPet[197] = True
        self.projPet[198] = True
        self.projPet[199] = True
        self.projPet[200] = True
        self.projPet[208] = True
        self.projPet[209] = True
        self.projPet[210] = True
        self.projPet[211] = True
        self.projPet[236] = True
        self.projPet[268] = True
        self.projPet[269] = True
        self.projPet[353] = True
        self.projPet[373] = True
        self.projPet[375] = True
        self.projPet[380] = True
        self.projPet[387] = True
        self.projPet[388] = True
        self.projPet[390] = True
        self.projPet[391] = True
        self.projPet[392] = True
        self.projPet[393] = True
        self.projPet[394] = True
        self.projPet[395] = True
        self.projPet[1093] = True
        self.projPet[1094] = True
        self.projPet[398] = True
        self.projPet[407] = True
        self.projPet[423] = True
        self.projPet[533] = True
        self.projPet[613] = True
        self.projPet[623] = True
        self.projPet[625] = True
        self.projPet[626] = True
        self.projPet[627] = True
        self.projPet[628] = True
        self.projPet[755] = True
        self.projPet[758] = True
        self.projPet[759] = True
        self.projPet[774] = True
        self.projPet[815] = True
        self.projPet[816] = True
        self.projPet[817] = True
        self.projPet[821] = True
        self.projPet[825] = True
        self.projPet[831] = True
        self.projPet[833] = True
        self.projPet[834] = True
        self.projPet[835] = True
        self.projPet[854] = True
        self.projPet[858] = True
        self.projPet[859] = True
        self.projPet[860] = True
        self.projPet[864] = True
        self.projPet[875] = True
        self.projPet[946] = True
        self.projPet[951] = True
        self.projPet[963] = True
        self.projPet[970] = True
        self.projPet[1022] = True
        self.projPet[881] = True
        self.projPet[882] = True
        self.projPet[883] = True
        self.projPet[884] = True
        self.projPet[885] = True
        self.projPet[886] = True
        self.projPet[887] = True
        self.projPet[888] = True
        self.projPet[889] = True
        self.projPet[890] = True
        self.projPet[891] = True
        self.projPet[892] = True
        self.projPet[893] = True
        self.projPet[894] = True
        self.projPet[895] = True
        self.projPet[896] = True
        self.projPet[897] = True
        self.projPet[898] = True
        self.projPet[899] = True
        self.projPet[900] = True
        self.projPet[901] = True
        self.projPet[934] = True
        self.projPet[956] = True
        self.projPet[957] = True
        self.projPet[958] = True
        self.projPet[959] = True
        self.projPet[960] = True
        self.projPet[994] = True
        self.projPet[998] = True
        self.projPet[1003] = True
        self.projPet[1004] = True
        self.projPet[1018] = True
        self.projPet[1056] = True
        self.projPet[1090] = True
        self.projPet[1027] = True
        self.projPet[1046] = True
        self.projPet[1050] = True
        self.projPet[1095] = True
        self.projPet[1096] = True
        self.tileLighted[237] = True
        self.tileLighted[27] = True
        self.tileLighted[381] = True
        self.tileLighted[534] = True
        self.tileLighted[536] = True
        self.tileLighted[539] = True
        self.tileLighted[625] = True
        self.tileLighted[627] = True
        self.tileLighted[184] = True
        self.tileLighted[463] = True
        self.tileLighted[491] = True
        self.slimeRainNPC[1] = True
        self.debuff[158] = True
        self.debuff[160] = True
        self.debuff[20] = True
        self.debuff[21] = True
        self.debuff[22] = True
        self.debuff[23] = True
        self.debuff[24] = True
        self.debuff[25] = True
        self.debuff[28] = True
        self.debuff[30] = True
        self.debuff[31] = True
        self.debuff[32] = True
        self.debuff[33] = True
        self.debuff[34] = True
        self.debuff[35] = True
        self.debuff[36] = True
        self.debuff[37] = True
        self.debuff[38] = True
        self.debuff[39] = True
        self.debuff[44] = True
        self.debuff[46] = True
        self.debuff[47] = True
        self.debuff[67] = True
        self.debuff[68] = True
        self.debuff[69] = True
        self.debuff[70] = True
        self.debuff[80] = True
        self.debuff[86] = True
        self.debuff[87] = True
        self.debuff[88] = True
        self.debuff[89] = True
        self.debuff[94] = True
        self.debuff[103] = True
        self.debuff[119] = True
        self.debuff[120] = True
        self.debuff[137] = True
        self.debuff[145] = True
        self.debuff[146] = True
        self.debuff[147] = True
        self.debuff[148] = True
        self.debuff[149] = True
        self.debuff[156] = True
        self.debuff[157] = True
        self.debuff[350] = True
        self.debuff[163] = True
        self.debuff[164] = True
        self.debuff[144] = True
        self.debuff[194] = True
        self.debuff[195] = True
        self.debuff[196] = True
        self.debuff[197] = True
        self.debuff[199] = True
        self.debuff[215] = True
        self.debuff[320] = True
        self.debuff[321] = True
        self.debuff[332] = True
        self.debuff[333] = True
        self.debuff[334] = True
        self.debuff[353] = True
        self.debuff[323] = True
        self.debuff[324] = True
        self.debuff[43] = True
        self.debuff[153] = True
        self.debuff[203] = True
        self.debuff[204] = True
        self.debuff[169] = True
        self.debuff[189] = True
        self.debuff[183] = True
        self.debuff[186] = True
        self.debuff[344] = True
        self.debuff[72] = True
        self.pvpBuff[20] = True
        self.pvpBuff[70] = True
        self.pvpBuff[24] = True
        self.pvpBuff[323] = True
        self.pvpBuff[31] = True
        self.pvpBuff[39] = True
        self.pvpBuff[44] = True
        self.pvpBuff[324] = True
        self.pvpBuff[69] = True
        self.pvpBuff[103] = True
        self.pvpBuff[119] = True
        self.pvpBuff[120] = True
        self.pvpBuff[137] = True
        self.pvpBuff[320] = True
        self.pvpBuff[30] = True
        self.pvpBuff[36] = True
        self.meleeBuff[71] = True
        self.meleeBuff[73] = True
        self.meleeBuff[74] = True
        self.meleeBuff[75] = True
        self.meleeBuff[76] = True
        self.meleeBuff[77] = True
        self.meleeBuff[78] = True
        self.meleeBuff[79] = True
        self.buffNoSave[20] = True
        self.buffNoSave[22] = True
        self.buffNoSave[23] = True
        self.buffNoSave[24] = True
        self.buffNoSave[28] = True
        self.buffNoSave[30] = True
        self.buffNoSave[31] = True
        self.buffNoSave[34] = True
        self.buffNoSave[35] = True
        self.buffNoSave[37] = True
        self.buffNoSave[38] = True
        self.buffNoSave[39] = True
        self.buffNoSave[43] = True
        self.buffNoSave[44] = True
        self.buffNoSave[46] = True
        self.buffNoSave[47] = True
        self.buffNoSave[48] = True
        self.buffNoSave[58] = True
        self.buffNoSave[59] = True
        self.buffNoSave[60] = True
        self.buffNoSave[62] = True
        self.buffNoSave[63] = True
        self.buffNoSave[64] = True
        self.buffNoSave[67] = True
        self.buffNoSave[68] = True
        self.buffNoSave[69] = True
        self.buffNoSave[70] = True
        self.buffNoSave[72] = True
        self.buffNoSave[80] = True
        self.buffNoSave[87] = True
        self.buffNoSave[158] = True
        self.buffNoSave[146] = True
        self.buffNoSave[147] = True
        self.buffNoSave[215] = True
        self.buffNoSave[88] = True
        self.buffNoSave[89] = True
        self.buffNoSave[94] = True
        self.buffNoSave[95] = True
        self.buffNoSave[96] = True
        self.buffNoSave[97] = True
        self.buffNoSave[98] = True
        self.buffNoSave[99] = True
        self.buffNoSave[100] = True
        self.buffNoSave[103] = True
        self.buffNoSave[119] = True
        self.buffNoSave[120] = True
        self.buffNoSave[125] = True
        self.buffNoSave[126] = True
        self.buffNoSave[133] = True
        self.buffNoSave[134] = True
        self.buffNoSave[135] = True
        self.buffNoSave[139] = True
        self.buffNoSave[140] = True
        self.buffNoSave[137] = True
        self.buffNoSave[144] = True
        self.buffNoSave[161] = True
        self.buffNoSave[163] = True
        self.buffNoSave[164] = True
        self.buffNoSave[170] = True
        self.buffNoSave[171] = True
        self.buffNoSave[172] = True
        self.buffNoSave[182] = True
        self.buffNoSave[187] = True
        self.buffNoSave[188] = True
        self.buffNoSave[194] = True
        self.buffNoSave[195] = True
        self.buffNoSave[196] = True
        self.buffNoSave[197] = True
        self.buffNoSave[198] = True
        self.buffNoSave[199] = True
        self.buffNoSave[205] = True
        self.buffNoSave[213] = True
        self.buffNoSave[214] = True
        self.buffNoSave[263] = True
        self.buffNoSave[271] = True
        self.buffNoSave[322] = True
        self.buffNoSave[320] = True
        self.buffNoSave[321] = True
        self.buffNoSave[325] = True
        self.buffNoSave[335] = True
        self.buffNoSave[150] = True
        self.buffNoSave[93] = True
        self.buffNoSave[159] = True
        self.buffNoSave[29] = True
        self.buffNoSave[348] = True
        self.buffNoSave[366] = True
        self.buffNoSave[353] = True
        self.buffNoSave[355] = True
        self.buffNoSave[385] = True
        self.buffNoSave[386] = True
        for k in range(173, 182):
            self.buffNoSave[k] = True
        self.buffNoTimeDisplay[19] = True
        self.buffNoTimeDisplay[27] = True
        self.buffNoTimeDisplay[28] = True
        self.buffNoTimeDisplay[34] = True
        self.buffNoTimeDisplay[37] = True
        self.buffNoTimeDisplay[38] = True
        self.buffNoTimeDisplay[40] = True
        self.buffNoTimeDisplay[41] = True
        self.buffNoTimeDisplay[42] = True
        self.buffNoTimeDisplay[43] = True
        self.buffNoTimeDisplay[45] = True
        self.buffNoTimeDisplay[49] = True
        self.buffNoTimeDisplay[60] = True
        self.buffNoTimeDisplay[62] = True
        self.buffNoTimeDisplay[64] = True
        self.buffNoTimeDisplay[68] = True
        self.buffNoTimeDisplay[81] = True
        self.buffNoTimeDisplay[82] = True
        self.buffNoTimeDisplay[83] = True
        self.buffNoTimeDisplay[95] = True
        self.buffNoTimeDisplay[96] = True
        self.buffNoTimeDisplay[97] = True
        self.buffNoTimeDisplay[98] = True
        self.buffNoTimeDisplay[99] = True
        self.buffNoTimeDisplay[100] = True
        self.buffNoTimeDisplay[101] = True
        self.buffNoTimeDisplay[102] = True
        self.buffNoTimeDisplay[125] = True
        self.buffNoTimeDisplay[126] = True
        self.buffNoTimeDisplay[133] = True
        self.buffNoTimeDisplay[134] = True
        self.buffNoTimeDisplay[135] = True
        self.buffNoTimeDisplay[136] = True
        self.buffNoTimeDisplay[139] = True
        self.buffNoTimeDisplay[140] = True
        self.buffNoTimeDisplay[200] = True
        self.buffNoTimeDisplay[202] = True
        self.buffNoTimeDisplay[201] = True
        self.buffNoTimeDisplay[161] = True
        self.buffNoTimeDisplay[163] = True
        self.buffNoTimeDisplay[170] = True
        self.buffNoTimeDisplay[171] = True
        self.buffNoTimeDisplay[172] = True
        self.buffNoTimeDisplay[182] = True
        self.buffNoTimeDisplay[165] = True
        self.buffNoTimeDisplay[186] = True
        self.buffNoTimeDisplay[187] = True
        self.buffNoTimeDisplay[188] = True
        self.buffNoTimeDisplay[199] = True
        self.buffNoTimeDisplay[213] = True
        self.buffNoTimeDisplay[214] = True
        self.buffNoTimeDisplay[216] = True
        self.buffNoTimeDisplay[217] = True
        self.buffNoTimeDisplay[219] = True
        self.buffNoTimeDisplay[258] = True
        self.buffNoTimeDisplay[259] = True
        self.buffNoTimeDisplay[260] = True
        self.buffNoTimeDisplay[261] = True
        self.buffNoTimeDisplay[262] = True
        self.buffNoTimeDisplay[263] = True
        self.buffNoTimeDisplay[264] = True
        self.buffNoTimeDisplay[266] = True
        self.buffNoTimeDisplay[267] = True
        self.buffNoTimeDisplay[268] = True
        self.buffNoTimeDisplay[271] = True
        self.buffNoTimeDisplay[322] = True
        self.buffNoTimeDisplay[274] = True
        self.buffNoTimeDisplay[284] = True
        self.buffNoTimeDisplay[285] = True
        self.buffNoTimeDisplay[286] = True
        self.buffNoTimeDisplay[287] = True
        self.buffNoTimeDisplay[288] = True
        self.buffNoTimeDisplay[289] = True
        self.buffNoTimeDisplay[290] = True
        self.buffNoTimeDisplay[291] = True
        self.buffNoTimeDisplay[292] = True
        self.buffNoTimeDisplay[293] = True
        self.buffNoTimeDisplay[294] = True
        self.buffNoTimeDisplay[295] = True
        self.buffNoTimeDisplay[296] = True
        self.buffNoTimeDisplay[297] = True
        self.buffNoTimeDisplay[298] = True
        self.buffNoTimeDisplay[299] = True
        self.buffNoTimeDisplay[300] = True
        self.buffNoTimeDisplay[301] = True
        self.buffNoTimeDisplay[302] = True
        self.buffNoTimeDisplay[303] = True
        self.buffNoTimeDisplay[304] = True
        self.buffNoTimeDisplay[317] = True
        self.buffNoTimeDisplay[325] = True
        self.buffNoTimeDisplay[335] = True
        self.buffNoTimeDisplay[341] = True
        self.buffNoTimeDisplay[327] = True
        self.buffNoTimeDisplay[328] = True
        self.buffNoTimeDisplay[329] = True
        self.buffNoTimeDisplay[330] = True
        self.buffNoTimeDisplay[331] = True
        self.buffNoTimeDisplay[334] = True
        self.buffNoTimeDisplay[345] = True
        self.buffNoTimeDisplay[349] = True
        self.buffNoTimeDisplay[351] = True
        self.buffNoTimeDisplay[352] = True
        self.buffNoTimeDisplay[354] = True
        self.buffNoTimeDisplay[373] = True
        self.buffNoTimeDisplay[356] = True
        self.buffNoTimeDisplay[371] = True
        self.buffNoTimeDisplay[372] = True
        self.buffNoTimeDisplay[382] = True
        self.buffNoTimeDisplay[29] = True
        self.buffNoTimeDisplay[159] = True
        self.buffNoTimeDisplay[150] = True
        self.buffNoTimeDisplay[93] = True
        self.buffNoTimeDisplay[348] = True
        self.buffNoTimeDisplay[353] = True
        self.buffNoTimeDisplay[355] = True
        self.buffNoTimeDisplay[366] = True
        self.buffNoTimeDisplay[385] = True
        self.buffNoTimeDisplay[386] = True
        self.persistentBuff[71] = True
        self.persistentBuff[73] = True
        self.persistentBuff[74] = True
        self.persistentBuff[75] = True
        self.persistentBuff[76] = True
        self.persistentBuff[77] = True
        self.persistentBuff[78] = True
        self.persistentBuff[79] = True
        for _ in range(0, self.BuffID_Count):
            pass
            # if (BuffID.Sets.MountType[l] != -1)
            # {
            #     Main.buffNoTimeDisplay[l] = True;
            #     Main.buffNoSave[l] = True;
            # }
        self.vanityPet[40] = True
        self.vanityPet[41] = True
        self.vanityPet[42] = True
        self.vanityPet[45] = True
        self.vanityPet[50] = True
        self.vanityPet[51] = True
        self.vanityPet[52] = True
        self.vanityPet[53] = True
        self.vanityPet[54] = True
        self.vanityPet[55] = True
        self.vanityPet[56] = True
        self.vanityPet[61] = True
        self.vanityPet[154] = True
        self.vanityPet[65] = True
        self.vanityPet[66] = True
        self.vanityPet[81] = True
        self.vanityPet[82] = True
        self.vanityPet[84] = True
        self.vanityPet[85] = True
        self.vanityPet[91] = True
        self.vanityPet[92] = True
        self.vanityPet[127] = True
        self.vanityPet[136] = True
        self.vanityPet[191] = True
        self.vanityPet[202] = True
        self.vanityPet[200] = True
        self.vanityPet[218] = True
        self.vanityPet[219] = True
        self.vanityPet[217] = True
        self.vanityPet[258] = True
        self.vanityPet[259] = True
        self.vanityPet[260] = True
        self.vanityPet[261] = True
        self.vanityPet[262] = True
        self.vanityPet[264] = True
        self.vanityPet[266] = True
        self.vanityPet[267] = True
        self.vanityPet[268] = True
        self.vanityPet[274] = True
        self.vanityPet[284] = True
        self.vanityPet[285] = True
        self.vanityPet[286] = True
        self.vanityPet[287] = True
        self.vanityPet[288] = True
        self.vanityPet[289] = True
        self.vanityPet[290] = True
        self.vanityPet[291] = True
        self.vanityPet[292] = True
        self.vanityPet[293] = True
        self.vanityPet[295] = True
        self.vanityPet[296] = True
        self.vanityPet[297] = True
        self.vanityPet[300] = True
        self.vanityPet[301] = True
        self.vanityPet[302] = True
        self.vanityPet[303] = True
        self.vanityPet[304] = True
        self.vanityPet[317] = True
        self.vanityPet[341] = True
        self.vanityPet[327] = True
        self.vanityPet[328] = True
        self.vanityPet[329] = True
        self.vanityPet[330] = True
        self.vanityPet[331] = True
        self.vanityPet[345] = True
        self.vanityPet[349] = True
        self.vanityPet[351] = True
        self.vanityPet[352] = True
        self.vanityPet[354] = True
        self.vanityPet[373] = True
        self.vanityPet[382] = True
        self.vanityPet[356] = True
        self.vanityPet[371] = True
        self.vanityPet[372] = True
        self.lightPet[19] = True
        self.lightPet[155] = True
        self.lightPet[27] = True
        self.lightPet[101] = True
        self.lightPet[102] = True
        self.lightPet[57] = True
        self.lightPet[190] = True
        self.lightPet[152] = True
        self.lightPet[201] = True
        self.lightPet[294] = True
        self.lightPet[298] = True
        self.lightPet[299] = True
        self.tileFlame[4] = True
        self.tileFlame[33] = True
        self.tileFlame[34] = True
        self.tileFlame[35] = True
        self.tileFlame[42] = True
        self.tileFlame[49] = True
        self.tileFlame[93] = True
        self.tileFlame[98] = True
        self.tileFlame[100] = True
        self.tileFlame[173] = True
        self.tileFlame[174] = True
        self.tileFlame[372] = True
        self.tileFlame[646] = True
        self.tileRope[213] = True
        self.tileRope[214] = True
        self.tileRope[353] = True
        self.tileRope[365] = True
        self.tileRope[366] = True
        self.tileRope[504] = True
        self.tileRope[449] = True
        self.tileRope[450] = True
        self.tileRope[451] = True
        self.tilePile[330] = True
        self.tilePile[331] = True
        self.tilePile[332] = True
        self.tilePile[333] = True
        for m in range(0, self.NPCID_Count):
            self.npcCatchable[m] = False
        self.npcCatchable[46] = True
        self.npcCatchable[55] = True
        self.npcCatchable[74] = True
        self.npcCatchable[148] = True
        self.npcCatchable[149] = True
        self.npcCatchable[297] = True
        self.npcCatchable[298] = True
        self.npcCatchable[299] = True
        self.npcCatchable[300] = True
        self.npcCatchable[355] = True
        self.npcCatchable[356] = True
        self.npcCatchable[357] = True
        self.npcCatchable[358] = True
        self.npcCatchable[359] = True
        self.npcCatchable[360] = True
        self.npcCatchable[361] = True
        self.npcCatchable[362] = True
        self.npcCatchable[363] = True
        self.npcCatchable[364] = True
        self.npcCatchable[365] = True
        self.npcCatchable[366] = True
        self.npcCatchable[367] = True
        self.npcCatchable[374] = True
        self.npcCatchable[377] = True
        self.npcCatchable[539] = True
        self.npcCatchable[538] = True
        self.npcCatchable[671] = True
        self.npcCatchable[672] = True
        self.npcCatchable[673] = True
        self.npcCatchable[674] = True
        self.npcCatchable[675] = True
        self.npcCatchable[484] = True
        self.npcCatchable[485] = True
        self.npcCatchable[486] = True
        self.npcCatchable[487] = True
        self.npcCatchable[583] = True
        self.npcCatchable[584] = True
        self.npcCatchable[585] = True
        self.npcCatchable[592] = True
        self.npcCatchable[593] = True
        self.npcCatchable[595] = True
        self.npcCatchable[596] = True
        self.npcCatchable[597] = True
        self.npcCatchable[598] = True
        self.npcCatchable[599] = True
        self.npcCatchable[600] = True
        self.npcCatchable[601] = True
        self.npcCatchable[604] = True
        self.npcCatchable[605] = True
        self.npcCatchable[602] = True
        self.npcCatchable[603] = True
        self.npcCatchable[606] = True
        self.npcCatchable[607] = True
        self.npcCatchable[608] = True
        self.npcCatchable[609] = True
        self.npcCatchable[610] = True
        self.npcCatchable[611] = True
        self.npcCatchable[612] = True
        self.npcCatchable[613] = True
        self.npcCatchable[614] = True
        self.npcCatchable[616] = True
        self.npcCatchable[617] = True
        self.npcCatchable[626] = True
        self.npcCatchable[627] = True
        self.npcCatchable[639] = True
        self.npcCatchable[640] = True
        self.npcCatchable[641] = True
        self.npcCatchable[642] = True
        self.npcCatchable[643] = True
        self.npcCatchable[644] = True
        self.npcCatchable[645] = True
        self.npcCatchable[646] = True
        self.npcCatchable[647] = True
        self.npcCatchable[648] = True
        self.npcCatchable[649] = True
        self.npcCatchable[650] = True
        self.npcCatchable[651] = True
        self.npcCatchable[652] = True
        self.npcCatchable[653] = True
        self.npcCatchable[654] = True
        self.npcCatchable[655] = True
        self.npcCatchable[661] = True
        self.npcCatchable[669] = True
        self.npcCatchable[677] = True
        self.npcCatchable[688] = True
        for n in range(442, 449):
            self.npcCatchable[n] = True
        self.SetTileValue()
        self.tileSpelunker[6] = True
        self.tileSpelunker[7] = True
        self.tileSpelunker[8] = True
        self.tileSpelunker[9] = True
        self.tileSpelunker[12] = True
        self.tileSpelunker[21] = True
        self.tileSpelunker[467] = True
        self.tileSpelunker[441] = True
        self.tileSpelunker[468] = True
        self.tileSpelunker[28] = True
        self.tileSpelunker[107] = True
        self.tileSpelunker[108] = True
        self.tileSpelunker[111] = True
        self.tileSpelunker[63] = True
        self.tileSpelunker[64] = True
        self.tileSpelunker[65] = True
        self.tileSpelunker[66] = True
        self.tileSpelunker[67] = True
        self.tileSpelunker[68] = True
        self.tileSpelunker[566] = True
        self.tileSpelunker[166] = True
        self.tileSpelunker[167] = True
        self.tileSpelunker[168] = True
        self.tileSpelunker[169] = True
        self.tileSpelunker[178] = True
        self.tileSpelunker[211] = True
        self.tileSpelunker[221] = True
        self.tileSpelunker[222] = True
        self.tileSpelunker[223] = True
        self.tileSpelunker[236] = True
        self.tileSpelunker[702] = True
        self.tileSpelunker[37] = True
        self.tileSpelunker[407] = True
        self.tileSpelunker[227] = True
        self.tileSpelunker[84] = True
        self.tileSpelunker[83] = True
        self.tileSpelunker[404] = True
        self.tileSpelunker[242] = True
        self.tileSpelunker[240] = True
        self.tileSpelunker[246] = True
        self.tileSpelunker[245] = True
        self.tileSpelunker[105] = True
        self.tileSpelunker[349] = True
        self.tileSpelunker[337] = True
        self.tileSpelunker[531] = True
        self.tileSpelunker[506] = True
        self.tileSpelunker[751] = True
        self.tileSpelunker[752] = True
        self.tileSolid[379] = True
        self.tileMergeDirt[249] = True
        self.tileBrick[268] = True
        self.tileBrick[262] = True
        self.tileBrick[267] = True
        self.tileBrick[265] = True
        self.tileBrick[266] = True
        self.tileBrick[264] = True
        self.tileBrick[263] = True
        self.tileBrick[261] = True
        self.tileBrick[255] = True
        self.tileBrick[260] = True
        self.tileBrick[258] = True
        self.tileBrick[259] = True
        self.tileBrick[257] = True
        self.tileBrick[256] = True
        self.tileSolid[371] = True
        self.tileMergeDirt[371] = True
        self.tileBlockLight[371] = True
        self.tileBouncy[371] = True
        self.tileBouncy[448] = True
        self.tileBouncy[446] = True
        self.tileBouncy[447] = True
        self.tileFrameImportant[377] = True
        self.tileFrameImportant[373] = True
        self.tileFrameImportant[375] = True
        self.tileFrameImportant[374] = True
        self.tileFrameImportant[461] = True
        self.tileFrameImportant[709] = True
        self.tileNoFail[373] = True
        self.tileNoFail[375] = True
        self.tileNoFail[374] = True
        self.tileNoFail[461] = True
        self.tileNoFail[709] = True
        self.tileLighted[646] = True
        self.tileFrameImportant[646] = True
        self.tileWaterDeath[646] = True
        self.tileLavaDeath[646] = True
        self.tileLighted[372] = True
        self.tileFrameImportant[372] = True
        self.tileWaterDeath[372] = True
        self.tileLavaDeath[372] = True
        self.tileSolid[357] = True
        self.tileBrick[357] = True
        self.tileBrick[311] = True
        self.tileSolid[408] = True
        self.tileMergeDirt[408] = True
        self.tileBrick[408] = True
        self.tileBlockLight[408] = True
        self.tileSolid[409] = True
        self.tileBrick[409] = True
        self.tileBlockLight[409] = True
        self.tileSolid[669] = True
        self.tileBrick[669] = True
        self.tileBlockLight[669] = True
        self.tileSolid[670] = True
        self.tileBrick[670] = True
        self.tileBlockLight[670] = True
        self.tileSolid[671] = True
        self.tileBrick[671] = True
        self.tileBlockLight[671] = True
        self.tileSolid[672] = True
        self.tileBrick[672] = True
        self.tileBlockLight[672] = True
        self.tileSolid[673] = True
        self.tileBrick[673] = True
        self.tileBlockLight[673] = True
        self.tileSolid[674] = True
        self.tileBrick[674] = True
        self.tileBlockLight[674] = True
        self.tileSolid[675] = True
        self.tileBrick[675] = True
        self.tileBlockLight[675] = True
        self.tileSolid[676] = True
        self.tileBrick[676] = True
        self.tileBlockLight[676] = True
        self.tileSolid[677] = True
        self.tileBrick[677] = True
        self.tileBlockLight[677] = True
        self.tileMergeDirt[677] = True
        self.tileSolid[678] = True
        self.tileBrick[678] = True
        self.tileBlockLight[678] = True
        self.tileMergeDirt[678] = True
        self.tileSolid[679] = True
        self.tileBrick[679] = True
        self.tileBlockLight[679] = True
        self.tileMergeDirt[679] = True
        self.tileSolid[680] = True
        self.tileBrick[680] = True
        self.tileBlockLight[680] = True
        self.tileMergeDirt[680] = True
        self.tileSolid[681] = True
        self.tileBrick[681] = True
        self.tileBlockLight[681] = True
        self.tileMergeDirt[681] = True
        self.tileSolid[682] = True
        self.tileBrick[682] = True
        self.tileBlockLight[682] = True
        self.tileMergeDirt[682] = True
        self.tileSolid[683] = True
        self.tileBrick[683] = True
        self.tileBlockLight[683] = True
        self.tileMergeDirt[683] = True
        self.tileSolid[684] = True
        self.tileBrick[684] = True
        self.tileBlockLight[684] = True
        self.tileMergeDirt[684] = True
        self.tileSolid[685] = True
        self.tileBrick[685] = True
        self.tileBlockLight[685] = True
        self.tileMergeDirt[685] = True
        self.tileSolid[686] = True
        self.tileBrick[686] = True
        self.tileBlockLight[686] = True
        self.tileMergeDirt[686] = True
        self.tileSolid[666] = True
        self.tileBlockLight[666] = True
        self.tileBrick[666] = True
        self.tileMergeDirt[666] = True
        self.tileNoFail[666] = True
        self.tileSolid[415] = True
        self.tileBrick[415] = True
        self.tileLighted[415] = True
        self.tileBlockLight[415] = True
        self.tileSolid[416] = True
        self.tileBrick[416] = True
        self.tileLighted[416] = True
        self.tileBlockLight[416] = True
        self.tileSolid[417] = True
        self.tileBrick[417] = True
        self.tileLighted[417] = True
        self.tileBlockLight[417] = True
        self.tileSolid[418] = True
        self.tileBrick[418] = True
        self.tileLighted[418] = True
        self.tileBlockLight[418] = True
        self.tileSolid[498] = True
        self.tileBrick[498] = True
        self.tileBlockLight[498] = True
        self.tileBrick[37] = True
        self.tileBrick[117] = True
        self.tileBrick[25] = True
        self.tileBrick[203] = True
        self.tileSolid[232] = True
        self.tileSolid[311] = True
        self.tileBlockLight[311] = True
        self.tileSolid[312] = True
        self.tileBlockLight[313] = True
        self.tileSolid[313] = True
        self.tileBlockLight[312] = True
        self.tileMergeDirt[311] = True
        self.tileSolid[315] = True
        self.tileBlockLight[315] = True
        self.tileMergeDirt[315] = True
        self.tileBrick[315] = True
        self.tileSolid[641] = True
        self.tileBlockLight[641] = True
        self.tileMergeDirt[641] = True
        self.tileBrick[641] = True
        self.tileSolid[659] = True
        self.tileBlockLight[659] = True
        self.tileLighted[659] = True
        self.tileBrick[659] = True
        self.tileSolid[667] = True
        self.tileBlockLight[667] = True
        self.tileBrick[667] = True
        self.tileLighted[667] = True
        self.tileMergeDirt[667] = True
        self.tileSolid[321] = True
        self.tileSolid[322] = True
        self.tileBlockLight[321] = True
        self.tileBlockLight[322] = True
        self.tileMergeDirt[321] = True
        self.tileMergeDirt[322] = True
        self.tileBrick[321] = True
        self.tileBrick[322] = True
        self.tileSolid[635] = True
        self.tileBlockLight[635] = True
        self.tileMergeDirt[635] = True
        self.tileBrick[635] = True
        self.tileFrameImportant[639] = True
        self.tileLavaDeath[639] = True
        self.tileSpelunker[639] = True
        self.tileShine[639] = 300
        self.tileShine2[639] = True
        self.tileLavaDeath[668] = True
        self.tileSolid[668] = True
        self.tileBlockLight[668] = True
        self.tileShine[239] = 1100
        self.tileSolid[239] = True
        self.tileSolidTop[239] = True
        self.tileSolid[380] = True
        self.tileSolidTop[380] = True
        self.tileFrameImportant[358] = True
        self.tileFrameImportant[359] = True
        self.tileFrameImportant[360] = True
        self.tileFrameImportant[361] = True
        self.tileFrameImportant[362] = True
        self.tileFrameImportant[363] = True
        self.tileFrameImportant[364] = True
        self.tileFrameImportant[391] = True
        self.tileLighted[391] = True
        self.tileFrameImportant[392] = True
        self.tileFrameImportant[393] = True
        self.tileFrameImportant[394] = True
        self.tileFrameImportant[542] = True
        self.tileFrameImportant[505] = True
        self.tileFrameImportant[521] = True
        self.tileFrameImportant[522] = True
        self.tileFrameImportant[523] = True
        self.tileFrameImportant[524] = True
        self.tileFrameImportant[525] = True
        self.tileFrameImportant[526] = True
        self.tileFrameImportant[527] = True
        self.tileFrameImportant[543] = True
        self.tileFrameImportant[568] = True
        self.tileFrameImportant[569] = True
        self.tileFrameImportant[570] = True
        self.tileFrameImportant[598] = True
        self.tileFrameImportant[356] = True
        self.tileFrameImportant[663] = True
        self.tileFrameImportant[334] = True
        self.tileFrameImportant[440] = True
        self.tileFrameImportant[471] = True
        self.tileFrameImportant[300] = True
        self.tileFrameImportant[301] = True
        self.tileFrameImportant[302] = True
        self.tileFrameImportant[303] = True
        self.tileFrameImportant[304] = True
        self.tileFrameImportant[305] = True
        self.tileFrameImportant[306] = True
        self.tileFrameImportant[307] = True
        self.tileFrameImportant[308] = True
        self.tileFrameImportant[354] = True
        self.tileLighted[354] = True
        self.tileFrameImportant[499] = True
        self.tileFrameImportant[355] = True
        self.tileFrameImportant[699] = True
        self.tileFrameImportant[324] = True
        self.tileObsidianKill[324] = True
        self.tileLavaDeath[324] = True
        self.tileFrameImportant[463] = True
        self.tileFrameImportant[491] = True
        self.tileFrameImportant[464] = True
        self.tileFrameImportant[466] = True
        self.tileFrameImportant[419] = True
        self.tileFrameImportant[442] = True
        self.tileFrameImportant[443] = True
        self.tileFrameImportant[444] = True
        self.tileFrameImportant[420] = True
        self.tileFrameImportant[423] = True
        self.tileFrameImportant[424] = True
        self.tileFrameImportant[428] = True
        self.tileFrameImportant[520] = True
        self.tileFrameImportant[429] = True
        self.tileFrameImportant[445] = True
        self.tileFrameImportant[476] = True
        self.tileFrameImportant[283] = True
        self.tileFrameImportant[288] = True
        self.tileFrameImportant[289] = True
        self.tileFrameImportant[290] = True
        self.tileFrameImportant[291] = True
        self.tileFrameImportant[292] = True
        self.tileFrameImportant[293] = True
        self.tileFrameImportant[294] = True
        self.tileFrameImportant[295] = True
        self.tileFrameImportant[296] = True
        self.tileFrameImportant[297] = True
        self.tileFrameImportant[316] = True
        self.tileFrameImportant[317] = True
        self.tileFrameImportant[318] = True
        self.tileLargeFrames[284] = 1
        self.wallHouse[224] = True
        self.wallLargeFrames[224] = 2
        self.wallHouse[323] = True
        self.wallLargeFrames[323] = 2
        self.wallHouse[324] = True
        self.wallLargeFrames[324] = 2
        self.wallHouse[325] = True
        self.wallLargeFrames[325] = 2
        self.wallHouse[326] = True
        self.wallLargeFrames[326] = 2
        self.wallHouse[327] = True
        self.wallLargeFrames[327] = 2
        self.wallHouse[328] = True
        self.wallLargeFrames[328] = 2
        self.wallHouse[329] = True
        self.wallLargeFrames[329] = 2
        self.wallHouse[330] = True
        self.wallLargeFrames[330] = 2
        self.wallHouse[331] = True
        self.wallHouse[332] = True
        self.wallHouse[333] = True
        self.wallHouse[334] = True
        self.wallHouse[335] = True
        self.wallHouse[336] = True
        self.wallHouse[337] = True
        self.wallHouse[338] = True
        self.wallHouse[339] = True
        self.wallHouse[340] = True
        self.wallHouse[341] = True
        self.wallHouse[342] = True
        self.wallHouse[343] = True
        self.wallHouse[344] = True
        self.wallHouse[345] = True
        self.wallHouse[346] = True
        self.wallHouse[60] = True
        self.wallHouse[225] = True
        self.wallHouse[226] = True
        self.wallHouse[227] = True
        self.wallHouse[231] = True
        self.wallHouse[232] = True
        self.wallHouse[233] = True
        self.wallHouse[235] = True
        self.wallHouse[234] = True
        self.wallHouse[312] = True
        self.wallHouse[313] = True
        self.wallHouse[237] = True
        self.wallHouse[238] = True
        self.wallHouse[239] = True
        self.wallHouse[240] = True
        self.tileLargeFrames[409] = 2
        self.tileLargeFrames[669] = 2
        self.tileLargeFrames[670] = 2
        self.tileLargeFrames[671] = 2
        self.tileLargeFrames[672] = 2
        self.tileLargeFrames[673] = 2
        self.tileLargeFrames[674] = 2
        self.tileLargeFrames[675] = 2
        self.tileLargeFrames[676] = 2
        self.tileFrameImportant[410] = True
        self.tileFrameImportant[480] = True
        self.tileFrameImportant[509] = True
        self.tileFrameImportant[657] = True
        self.tileFrameImportant[658] = True
        self.tileLighted[658] = True
        self.tileFrameImportant[720] = True
        self.tileFrameImportant[721] = True
        self.tileFrameImportant[725] = True
        self.tileFrameImportant[733] = True
        self.tileFrameImportant[751] = True
        self.tileFrameImportant[752] = True
        self.wallHouse[173] = True
        self.wallHouse[183] = True
        self.wallHouse[179] = True
        self.wallLargeFrames[179] = 1
        self.tileSolid[367] = True
        self.tileBlockLight[367] = True
        self.tileMergeDirt[367] = True
        self.tileSolid[357] = True
        self.tileBlockLight[357] = True
        self.tileLargeFrames[357] = 1
        self.tileBlendAll[357] = True
        self.wallHouse[184] = True
        self.wallHouse[181] = True
        self.tileSolid[368] = True
        self.tileBlockLight[368] = True
        self.tileMergeDirt[368] = True
        self.tileSolid[369] = True
        self.tileBlockLight[369] = True
        self.tileBrick[369] = True
        self.tileMergeDirt[369] = True
        self.wallHouse[186] = True
        self.tileLargeFrames[325] = 1
        self.tileSolid[325] = True
        self.tileBlockLight[325] = True
        self.wallLargeFrames[146] = 1
        self.wallLargeFrames[147] = 1
        self.wallLargeFrames[167] = 1
        self.wallLargeFrames[185] = 2
        self.wallLargeFrames[274] = 2
        self.tileSolid[460] = True
        self.tileSolid[326] = True
        self.tileBlockLight[326] = True
        self.tileBrick[326] = True
        self.tileSolid[458] = True
        self.tileBlockLight[458] = True
        self.tileBrick[458] = True
        self.tileSolid[459] = True
        self.tileBrick[459] = True
        self.tileSolid[327] = True
        self.tileBlockLight[327] = True
        self.tileBrick[327] = True
        self.tileSolid[345] = True
        self.tileBlockLight[345] = True
        self.tileBrick[345] = True
        self.tileLighted[327] = True
        self.tileSolid[708] = True
        self.tileBlockLight[708] = True
        self.tileBrick[708] = True
        self.tileLighted[708] = True
        self.tileSolid[722] = True
        self.tileBlockLight[722] = True
        self.tileBrick[722] = True
        self.tileMergeDirt[722] = True
        self.tileSolid[734] = True
        self.tileBrick[734] = True
        self.tileMergeDirt[734] = True
        self.tileBlockLight[734] = True
        self.tileSolid[735] = True
        self.tileBrick[735] = True
        self.tileBlockLight[735] = True
        self.tileLargeFrames[735] = 2
        self.tileSolid[736] = True
        self.tileBrick[736] = True
        self.tileBlockLight[736] = True
        self.tileLargeFrames[736] = 1
        self.wallLargeFrames[354] = 1
        self.tileSolid[737] = True
        self.tileBrick[737] = True
        self.tileBlockLight[737] = True
        self.tileLargeFrames[737] = 2
        self.wallLargeFrames[355] = 2
        self.tileSolid[738] = True
        self.tileBrick[738] = True
        self.tileBlockLight[738] = True
        self.tileSolid[739] = True
        self.tileBlockLight[739] = True
        self.tileLighted[739] = True
        self.tileSolid[741] = True
        self.tileBrick[741] = True
        self.tileBlockLight[741] = True
        self.tileLargeFrames[741] = 2
        self.wallLargeFrames[358] = 2
        self.tileSolid[742] = True
        self.tileBrick[742] = True
        self.tileBlockLight[742] = True
        self.tileLargeFrames[742] = 2
        self.wallLargeFrames[359] = 2
        self.tileSolid[743] = True
        self.tileBrick[743] = True
        self.tileBlockLight[743] = True
        self.tileLargeFrames[743] = 2
        self.tileSolid[744] = True
        self.tileBrick[744] = True
        self.tileBlockLight[744] = True
        self.tileMergeDirt[744] = True
        self.tileSolid[745] = True
        self.tileBrick[745] = True
        self.tileBlockLight[745] = True
        self.tileLargeFrames[745] = 2
        self.wallLargeFrames[362] = 2
        self.tileSolid[750] = True
        self.tileBrick[750] = True
        self.tileMergeDirt[750] = True
        self.tileBlockLight[750] = True
        self.tileSolid[746] = True
        self.tileBrick[746] = True
        self.tileBlockLight[746] = True
        self.tileLargeFrames[746] = 2
        self.wallLargeFrames[363] = 2
        self.tileSolid[747] = True
        self.tileBrick[747] = True
        self.tileBlockLight[747] = True
        self.tileSolid[748] = True
        self.tileBrick[748] = True
        self.tileSolid[749] = True
        self.tileBrick[749] = True
        self.tileBlockLight[749] = True
        self.tileLargeFrames[749] = 2
        self.wallLargeFrames[366] = 2
        self.tileSolid[740] = True
        self.tileBrick[740] = True
        self.tileMergeDirt[740] = True
        self.tileBlockLight[740] = True
        self.tileSolid[328] = True
        self.tileBrick[328] = True
        self.tileSolid[329] = True
        self.tileBrick[329] = True
        self.tileBlockLight[329] = True
        self.tileSolid[507] = True
        self.tileBlockLight[507] = True
        self.tileBrick[507] = True
        self.tileSolid[508] = True
        self.tileBlockLight[508] = True
        self.tileBrick[508] = True
        self.tileLighted[336] = True
        self.tileLighted[340] = True
        self.tileLighted[341] = True
        self.tileLighted[342] = True
        self.tileLighted[343] = True
        self.tileLighted[344] = True
        self.tileLighted[349] = True
        self.tileLighted[598] = True
        self.tileSolid[421] = True
        self.tileBlockLight[421] = True
        self.tileSolid[422] = True
        self.tileBlockLight[422] = True
        self.tileSolid[426] = True
        self.tileBlockLight[426] = True
        self.tileSolid[430] = True
        self.tileBlockLight[430] = True
        self.tileSolid[431] = True
        self.tileBlockLight[431] = True
        self.tileSolid[432] = True
        self.tileBlockLight[432] = True
        self.tileSolid[433] = True
        self.tileBlockLight[433] = True
        self.tileSolid[434] = True
        self.tileBlockLight[434] = True
        for o in range(727, 733):
            self.tileSolid[o] = True
            self.tileBlockLight[o] = True
        self.tileSolid[446] = True
        self.tileSolid[447] = True
        self.tileSolid[448] = True
        self.tileFrameImportant[427] = True
        self.tileSolidTop[427] = True
        self.tileSolid[427] = True
        self.tileNoAttach[427] = True
        self.tileTable[427] = True
        self.tileLavaDeath[427] = True
        self.tileNoSunLight[427] = False
        self.tileSolid[476] = True
        for p in range(435, 440):
            self.tileFrameImportant[p] = True
            self.tileSolidTop[p] = True
            self.tileSolid[p] = True
            self.tileNoAttach[p] = True
            self.tileTable[p] = True
            self.tileLavaDeath[p] = True
            self.tileNoSunLight[p] = False
        self.tileSolid[284] = True
        self.tileBlockLight[284] = True
        self.tileSolid[346] = True
        self.tileBlockLight[346] = True
        self.tileLighted[346] = True
        self.tileShine[346] = 2000
        self.tileShine2[346] = True
        self.tileBrick[346] = True
        self.tileMergeDirt[346] = True
        self.tileSolid[347] = True
        self.tileBlockLight[347] = True
        self.tileLighted[347] = True
        self.tileShine[347] = 1900
        self.tileShine2[347] = True
        self.tileBrick[347] = True
        self.tileMergeDirt[347] = True
        self.tileSolid[348] = True
        self.tileBlockLight[348] = True
        self.tileLighted[348] = True
        self.tileShine[348] = 1800
        self.tileShine2[348] = True
        self.tileBrick[348] = True
        self.tileMergeDirt[348] = True
        self.tileSolid[350] = True
        self.tileBlockLight[350] = True
        self.tileLighted[350] = True
        self.tileBrick[350] = True
        self.tileMergeDirt[350] = True
        self.tileGlowMask[350] = 94
        self.tileGlowMask[390] = 130
        self.tileGlowMask[381] = 126
        self.tileGlowMask[517] = 258
        self.tileGlowMask[687] = 336
        self.tileGlowMask[534] = 259
        self.tileGlowMask[535] = 260
        self.tileGlowMask[689] = 338
        self.tileGlowMask[536] = 261
        self.tileGlowMask[537] = 262
        self.tileGlowMask[690] = 339
        self.tileGlowMask[539] = 263
        self.tileGlowMask[540] = 264
        self.tileGlowMask[688] = 337
        self.tileGlowMask[625] = 311
        self.tileGlowMask[626] = 312
        self.tileGlowMask[691] = 340
        self.tileGlowMask[627] = 313
        self.tileGlowMask[628] = 314
        self.tileGlowMask[692] = 341
        self.tileGlowMask[370] = 111
        self.tileGlowMask[429] = 214
        self.tileGlowMask[209] = 215
        self.tileGlowMask[445] = 214
        self.tileGlowMask[129] = -2
        self.tileGlowMask[633] = 326
        self.tileGlowMask[659] = 348
        self.tileGlowMask[667] = 349
        self.tileGlowMask[708] = 359
        self.tileGlowMask[699] = 353
        self.tileLighted[429] = True
        self.tileLighted[209] = True
        self.tileGlowMask[717] = 362
        self.tileSolid[717] = True
        self.tileSolid[718] = True
        self.tileSolid[719] = True
        self.tileLighted[719] = True
        self.tileLighted[717] = True
        self.tileLighted[718] = True
        self.tileGlowMask[410] = 201
        self.tileGlowMask[509] = 265
        self.tileGlowMask[658] = 333
        self.tileGlowMask[720] = 368
        self.tileGlowMask[721] = 369
        self.tileGlowMask[725] = 371
        self.tileSolid[370] = True
        self.tileBlockLight[370] = True
        self.tileLighted[370] = True
        self.tileShine[370] = 1900
        self.tileShine2[370] = True
        self.tileBrick[370] = True
        self.tileMergeDirt[370] = True
        self.tileContainer[21] = True
        self.tileContainer[467] = True
        self.tileContainer[88] = True
        self.tileContainer[470] = True
        self.tileContainer[475] = True
        self.tileSign[55] = True
        self.tileSign[85] = True
        self.tileSign[425] = True
        self.tileSign[573] = True
        self.tileSolid[383] = True
        self.tileBrick[383] = True
        self.tileBlockLight[383] = True
        self.tileSolid[385] = True
        self.tileBrick[385] = True
        self.tileBlockLight[385] = True
        self.tileSolid[472] = True
        self.tileBrick[472] = True
        self.tileMergeDirt[472] = True
        self.tileBlockLight[472] = True
        self.tileSolid[726] = True
        self.tileBlockLight[726] = True
        self.tileFrameImportant[726] = True
        self.tileSolid[473] = True
        self.tileBrick[473] = True
        self.tileMergeDirt[473] = True
        self.tileBlockLight[473] = True
        self.tileSolid[500] = True
        self.tileBrick[500] = True
        self.tileLighted[500] = True
        self.tileMergeDirt[500] = True
        self.tileBlockLight[500] = True
        self.tileSolid[501] = True
        self.tileBrick[501] = True
        self.tileLighted[501] = True
        self.tileMergeDirt[501] = True
        self.tileBlockLight[501] = True
        self.tileSolid[502] = True
        self.tileBrick[502] = True
        self.tileLighted[502] = True
        self.tileMergeDirt[502] = True
        self.tileBlockLight[502] = True
        self.tileSolid[503] = True
        self.tileBrick[503] = True
        self.tileLighted[503] = True
        self.tileMergeDirt[503] = True
        self.tileBlockLight[503] = True
        self.tileSolid[541] = True
        self.tileBlockLight[541] = False
        self.tileSolid[546] = True
        self.tileBlockLight[546] = False
        self.tileSolid[557] = True
        self.tileBlockLight[557] = True
        self.tileSolid[474] = True
        self.tileBrick[474] = True
        self.tileMergeDirt[474] = True
        self.tileBlockLight[474] = True
        self.tileSolid[478] = True
        self.tileBrick[478] = True
        self.tileMergeDirt[478] = True
        self.tileBlockLight[478] = True
        self.tileSolid[479] = True
        self.tileBrick[479] = True
        self.tileMergeDirt[479] = True
        self.tileBlockLight[479] = True
        self.tileSolid[562] = True
        self.tileBrick[562] = True
        self.tileBlockLight[562] = True
        self.tileMergeDirt[562] = True
        self.tileSolid[563] = True
        self.tileBrick[563] = True
        self.tileBlockLight[563] = True
        self.tileMergeDirt[563] = True
        self.tileSolid[496] = True
        self.tileBrick[496] = True
        self.tileMergeDirt[496] = True
        self.tileBlockLight[496] = True
        self.tileSolid[495] = True
        self.tileBrick[495] = True
        self.tileMergeDirt[495] = True
        self.tileBlockLight[495] = True
        self.tileSolid[396] = True
        self.tileBlockLight[396] = True
        self.tileSolid[397] = True
        self.tileBlockLight[397] = True
        self.tileSolid[399] = True
        self.tileBlockLight[399] = True
        self.tileSolid[401] = True
        self.tileBlockLight[401] = True
        self.tileSolid[398] = True
        self.tileBlockLight[398] = True
        self.tileSolid[400] = True
        self.tileBlockLight[400] = True
        self.tileSolid[402] = True
        self.tileBlockLight[402] = True
        self.tileSolid[403] = True
        self.tileBlockLight[403] = True
        self.tileSolid[404] = True
        self.tileBlockLight[404] = True
        self.tileSolid[407] = True
        self.tileBlockLight[407] = True
        self.tileShine2[407] = True
        self.tileShine[407] = 1000
        self.tileFrameImportant[36] = True
        self.tileFrameImportant[275] = True
        self.tileFrameImportant[276] = True
        self.tileFrameImportant[277] = True
        self.tileFrameImportant[278] = True
        self.tileFrameImportant[279] = True
        self.tileFrameImportant[280] = True
        self.tileFrameImportant[281] = True
        self.tileFrameImportant[282] = True
        self.tileFrameImportant[285] = True
        self.tileFrameImportant[286] = True
        self.tileFrameImportant[414] = True
        self.tileFrameImportant[413] = True
        self.tileFrameImportant[309] = True
        self.tileFrameImportant[310] = True
        self.tileFrameImportant[339] = True
        self.tileFrameImportant[532] = True
        self.tileLighted[286] = True
        self.tileLighted[302] = True
        self.tileFrameImportant[298] = True
        self.tileFrameImportant[299] = True
        self.tileSolid[170] = True
        self.tileBlockLight[170] = True
        self.tileFrameImportant[171] = True
        self.tileLighted[171] = True
        self.tileFrameImportant[247] = True
        self.tileFrameImportant[245] = True
        self.tileFrameImportant[246] = True
        self.tileFrameImportant[239] = True
        self.tileFrameImportant[240] = True
        self.tileFrameImportant[241] = True
        self.tileFrameImportant[242] = True
        self.tileFrameImportant[243] = True
        self.tileFrameImportant[244] = True
        self.tileFrameImportant[254] = True
        self.tileSolid[221] = True
        self.tileBlockLight[221] = True
        self.tileMergeDirt[221] = True
        self.tileLighted[96] = True
        self.tileMergeDirt[250] = True
        self.tileSolid[272] = True
        self.tileBlockLight[272] = True
        self.tileSolid[229] = True
        self.tileBlockLight[229] = True
        self.tileMergeDirt[229] = True
        self.tileSolid[230] = True
        self.tileBlockLight[230] = True
        self.tileMergeDirt[230] = True
        self.tileSolid[222] = True
        self.tileBlockLight[222] = True
        self.tileMergeDirt[222] = True
        self.tileSolid[223] = True
        self.tileBlockLight[223] = True
        self.tileMergeDirt[223] = True
        self.tileSolid[224] = True
        self.tileBlockLight[224] = True
        self.tileFrameImportant[237] = True
        self.tileFrameImportant[238] = True
        self.tileSolid[225] = True
        self.tileBlockLight[225] = True
        self.tileBrick[225] = True
        self.tileSolid[226] = True
        self.tileBlockLight[226] = True
        self.tileBrick[226] = True
        self.tileSolid[235] = True
        self.tileBlockLight[235] = True
        self.tileFrameImportant[235] = True
        self.tileLighted[238] = True
        self.tileCut[254] = True
        self.tileFrameImportant[236] = True
        self.tileFrameImportant[702] = True
        self.tileCut[236] = True
        self.tileSolid[191] = True
        self.tileBrick[191] = True
        self.tileBlockLight[191] = True
        self.tileSolid[211] = True
        self.tileBlockLight[211] = True
        self.tileSolid[208] = True
        self.tileBrick[208] = True
        self.tileBlockLight[208] = True
        self.tileSolid[192] = True
        self.tileBlockLight[192] = True
        self.tileSolid[193] = True
        self.tileBrick[193] = True
        self.tileBlockLight[193] = True
        self.tileMergeDirt[193] = True
        self.tileSolid[194] = True
        self.tileBrick[194] = True
        self.tileBlockLight[194] = True
        self.tileSolid[195] = True
        self.tileBrick[195] = True
        self.tileMergeDirt[195] = True
        self.tileBlockLight[195] = True
        self.tileBlockLight[200] = True
        self.tileSolid[200] = True
        self.tileBrick[200] = True
        self.tileBlockLight[203] = True
        self.tileSolid[203] = True
        self.tileMergeDirt[203] = True
        self.tileBlockLight[204] = True
        self.tileSolid[204] = True
        self.tileMergeDirt[204] = True
        self.tileBlockLight[165] = True
        self.tileShine2[147] = True
        self.tileShine2[161] = True
        self.tileShine2[163] = True
        self.tileShine2[164] = True
        self.tileSolid[189] = True
        self.tileBlockLight[51] = True
        self.tileBlockLight[697] = True
        self.tileNoFail[51] = True
        self.tileNoFail[697] = True
        self.tileLighted[204] = True
        self.tileShine[204] = 1150
        self.tileShine2[204] = True
        self.tileSolid[190] = True
        self.tileBlockLight[190] = True
        self.tileBrick[190] = True
        self.tileSolid[198] = True
        self.tileMergeDirt[198] = True
        self.tileBrick[198] = True
        self.tileBlockLight[198] = True
        self.tileSolid[206] = True
        self.tileBlockLight[206] = True
        self.tileMergeDirt[206] = True
        self.tileBrick[206] = True
        self.tileBlockLight[234] = True
        self.tileSolid[248] = True
        self.tileSolid[249] = True
        self.tileSolid[250] = True
        self.tileBrick[248] = True
        self.tileBrick[249] = True
        self.tileBrick[250] = True
        self.tileSolid[251] = True
        self.tileSolid[252] = True
        self.tileBrick[252] = True
        self.tileSolid[253] = True
        self.tileBrick[253] = True
        self.tileMergeDirt[251] = True
        self.tileMergeDirt[252] = True
        self.tileMergeDirt[253] = True
        self.tileBlockLight[251] = True
        self.tileBlockLight[252] = True
        self.tileBlockLight[253] = True
        self.tileBlockLight[248] = True
        self.tileBlockLight[249] = True
        self.tileBlockLight[250] = True
        self.tileLargeFrames[273] = 1
        self.tileSolid[273] = True
        self.tileBlockLight[273] = True
        self.tileLargeFrames[274] = 1
        self.tileSolid[274] = True
        self.tileBlockLight[274] = True
        self.tileLargeFrames[618] = 1
        self.tileSolid[618] = True
        self.tileBlockLight[618] = True
        for q in range(255, 269):
            self.tileSolid[q] = True
            if q > 261:
                self.tileLighted[q] = True
                self.tileShine2[q] = True
        self.tileFrameImportant[269] = True
        self.tileFrameImportant[470] = True
        self.tileFrameImportant[475] = True
        self.tileFrameImportant[390] = True
        self.tileFrameImportant[597] = True
        self.tileLighted[597] = True
        self.tileNoAttach[390] = True
        self.tileLavaDeath[390] = True
        self.tileLighted[390] = True
        self.tileFrameImportant[617] = True
        self.wallHouse[168] = True
        self.wallHouse[169] = True
        self.wallHouse[142] = True
        self.wallHouse[143] = True
        self.wallHouse[144] = True
        self.wallHouse[149] = True
        self.wallHouse[151] = True
        self.wallHouse[150] = True
        self.wallHouse[152] = True
        self.wallHouse[145] = True
        self.wallHouse[148] = True
        self.wallHouse[175] = True
        self.wallHouse[176] = True
        self.wallHouse[182] = True
        for r in range(153, 167):
            self.wallHouse[r] = True
        self.wallHouse[146] = True
        self.wallHouse[147] = True
        self.wallHouse[149] = True
        self.wallHouse[167] = True
        self.wallHouse[168] = True
        self.wallHouse[133] = True
        self.wallHouse[134] = True
        self.wallHouse[135] = True
        self.wallHouse[136] = True
        self.wallHouse[137] = True
        self.wallHouse[75] = True
        self.wallHouse[76] = True
        self.wallHouse[78] = True
        self.wallHouse[82] = True
        self.wallHouse[77] = True
        self.wallHouse[1] = True
        self.wallHouse[4] = True
        self.wallHouse[5] = True
        self.wallHouse[6] = True
        self.wallHouse[10] = True
        self.wallHouse[11] = True
        self.wallHouse[12] = True
        self.wallHouse[16] = True
        self.wallHouse[17] = True
        self.wallHouse[18] = True
        self.wallHouse[19] = True
        self.wallHouse[20] = True
        self.wallHouse[21] = True
        self.wallHouse[22] = True
        self.wallHouse[23] = True
        self.wallHouse[24] = True
        self.wallHouse[25] = True
        self.wallHouse[26] = True
        self.wallHouse[27] = True
        self.wallHouse[29] = True
        self.wallHouse[30] = True
        self.wallHouse[31] = True
        self.wallHouse[32] = True
        self.wallHouse[33] = True
        self.wallHouse[34] = True
        self.wallHouse[35] = True
        self.wallHouse[36] = True
        self.wallHouse[37] = True
        self.wallHouse[38] = True
        self.wallHouse[39] = True
        self.wallHouse[41] = True
        self.wallHouse[42] = True
        self.wallHouse[43] = True
        self.wallHouse[44] = True
        self.wallHouse[45] = True
        self.wallHouse[46] = True
        self.wallHouse[47] = True
        self.wallHouse[66] = True
        self.wallHouse[67] = True
        self.wallHouse[68] = True
        self.wallHouse[72] = True
        self.wallHouse[73] = True
        self.wallHouse[107] = True
        self.wallHouse[106] = True
        self.wallHouse[245] = True
        self.wallHouse[315] = True
        self.wallHouse[316] = True
        self.wallHouse[317] = True
        self.wallHouse[109] = True
        self.wallHouse[110] = True
        self.wallHouse[111] = True
        self.wallHouse[112] = True
        self.wallHouse[113] = True
        self.wallHouse[114] = True
        self.wallHouse[115] = True
        self.wallHouse[116] = True
        self.wallHouse[117] = True
        self.wallHouse[118] = True
        self.wallHouse[119] = True
        self.wallHouse[120] = True
        self.wallHouse[121] = True
        self.wallHouse[122] = True
        self.wallHouse[123] = True
        self.wallHouse[124] = True
        self.wallHouse[125] = True
        self.wallHouse[108] = True
        self.wallHouse[100] = True
        self.wallHouse[101] = True
        self.wallHouse[102] = True
        self.wallHouse[103] = True
        self.wallHouse[104] = True
        self.wallHouse[105] = True
        self.wallHouse[84] = True
        self.wallHouse[74] = True
        self.wallHouse[241] = True
        self.wallHouse[85] = True
        self.wallHouse[88] = True
        self.wallHouse[89] = True
        self.wallHouse[90] = True
        self.wallHouse[91] = True
        self.wallHouse[92] = True
        self.wallHouse[93] = True
        self.wallHouse[126] = True
        self.wallHouse[127] = True
        self.wallHouse[128] = True
        self.wallHouse[129] = True
        self.wallHouse[130] = True
        self.wallHouse[131] = True
        self.wallHouse[132] = True
        self.wallHouse[138] = True
        self.wallHouse[139] = True
        self.wallHouse[140] = True
        self.wallHouse[141] = True
        self.wallHouse[177] = True
        self.wallHouse[172] = True
        self.wallHouse[242] = True
        self.wallHouse[243] = True
        self.wallHouse[174] = True
        self.wallHouse[230] = True
        self.wallHouse[228] = True
        self.wallHouse[229] = True
        self.wallHouse[236] = True
        self.wallHouse[319] = True
        self.wallHouse[318] = True
        self.wallHouse[321] = True
        self.wallHouse[322] = True
        self.wallHouse[320] = True
        self.wallHouse[347] = True
        self.wallHouse[348] = True
        self.wallHouse[351] = True
        self.wallHouse[352] = True
        self.wallHouse[353] = True
        self.wallHouse[354] = True
        self.wallHouse[355] = True
        self.wallHouse[356] = True
        self.wallHouse[357] = True
        self.wallHouse[358] = True
        self.wallHouse[359] = True
        self.wallHouse[360] = True
        self.wallHouse[361] = True
        self.wallHouse[362] = True
        self.wallHouse[363] = True
        self.wallHouse[364] = True
        self.wallHouse[365] = True
        self.wallHouse[366] = True
        self.wallHouse[246] = True
        self.wallHouse[247] = True
        self.wallHouse[248] = True
        self.wallHouse[249] = True
        self.wallHouse[250] = True
        self.wallHouse[251] = True
        self.wallHouse[252] = True
        self.wallHouse[253] = True
        self.wallHouse[254] = True
        self.wallHouse[255] = True
        self.wallHouse[314] = True
        self.wallHouse[256] = True
        self.wallHouse[257] = True
        self.wallHouse[258] = True
        self.wallHouse[259] = True
        self.wallHouse[260] = True
        self.wallHouse[261] = True
        self.wallHouse[262] = True
        self.wallHouse[263] = True
        self.wallHouse[264] = True
        self.wallHouse[265] = True
        self.wallHouse[266] = True
        self.wallHouse[267] = True
        self.wallHouse[268] = True
        self.wallHouse[269] = True
        self.wallHouse[270] = True
        self.wallHouse[271] = True
        self.wallHouse[272] = True
        self.wallHouse[273] = True
        self.wallHouse[274] = True
        self.wallHouse[275] = True
        self.wallHouse[276] = True
        self.wallHouse[277] = True
        self.wallHouse[278] = True
        self.wallHouse[279] = True
        self.wallHouse[280] = True
        self.wallHouse[281] = True
        self.wallHouse[282] = True
        self.wallHouse[283] = True
        self.wallHouse[284] = True
        self.wallHouse[285] = True
        self.wallHouse[286] = True
        self.wallHouse[287] = True
        self.wallHouse[288] = True
        self.wallHouse[289] = True
        self.wallHouse[290] = True
        self.wallHouse[291] = True
        self.wallHouse[292] = True
        self.wallHouse[293] = True
        self.wallHouse[294] = True
        self.wallHouse[295] = True
        self.wallHouse[296] = True
        self.wallHouse[297] = True
        self.wallHouse[298] = True
        self.wallHouse[299] = True
        self.wallHouse[300] = True
        self.wallHouse[301] = True
        self.wallHouse[302] = True
        self.wallHouse[303] = True
        self.wallHouse[304] = True
        self.wallHouse[305] = True
        self.wallHouse[306] = True
        self.wallHouse[307] = True
        self.wallHouse[308] = True
        self.wallHouse[309] = True
        self.wallHouse[310] = True
        self.wallHouse[311] = True
        self.wallLight[0] = True
        self.wallLight[21] = True
        self.wallLight[318] = True
        self.wallLight[106] = True
        self.wallLight[317] = True
        self.wallLight[107] = True
        self.wallLight[138] = True
        self.wallLight[140] = True
        self.wallLight[141] = True
        self.wallLight[139] = True
        self.wallLight[145] = True
        self.wallLight[150] = True
        self.wallLight[152] = True
        self.wallLight[245] = True
        self.wallLight[315] = True
        self.wallLight[168] = True
        for s in range(0, self.WallID_Count):
            self.wallDungeon[s] = False
        self.wallDungeon[7] = True
        self.wallDungeon[8] = True
        self.wallDungeon[9] = True
        self.wallDungeon[94] = True
        self.wallDungeon[95] = True
        self.wallDungeon[96] = True
        self.wallDungeon[97] = True
        self.wallDungeon[98] = True
        self.wallDungeon[99] = True
        self.SetupTileMerge()

    # Initialize_TileAndNPCData2
    def init_tile_and_npc_data2(self) -> None:
        self.critterCage = True
        for _ in range(0, 3500):
            self.AnimateTiles_CritterCages()
        self.critterCage = False
        self.tileBlockLight[549] = True
        self.tileBrick[477] = True
        self.tileSolid[477] = True
        self.tileBlockLight[477] = True
        self.tileBrick[492] = True
        self.tileSolid[492] = True
        self.tileBlockLight[492] = True
        self.tileSolidTop[275] = True
        self.tileSolidTop[280] = True
        self.tileSolidTop[276] = True
        self.tileSolidTop[277] = True
        self.tileSolidTop[278] = True
        self.tileSolidTop[279] = True
        self.tileSolidTop[281] = True
        self.tileSolidTop[605] = True
        self.tileSolidTop[604] = True
        self.tileSolidTop[603] = True
        self.tileSolidTop[602] = True
        self.tileSolidTop[601] = True
        self.tileSolidTop[599] = True
        self.tileSolidTop[600] = True
        self.tileSolidTop[612] = True
        self.tileSolidTop[611] = True
        self.tileSolidTop[610] = True
        self.tileSolidTop[609] = True
        self.tileSolidTop[608] = True
        self.tileSolidTop[606] = True
        self.tileSolidTop[607] = True
        self.tileSolidTop[558] = True
        self.tileSolidTop[554] = True
        self.tileSolidTop[553] = True
        self.tileSolidTop[551] = True
        self.tileSolidTop[550] = True
        self.tileSolidTop[542] = True
        self.tileSolidTop[413] = True
        self.tileSolidTop[309] = True
        self.tileSolidTop[297] = True
        self.tileSolidTop[296] = True
        self.tileSolidTop[645] = True
        self.tileSolidTop[643] = True
        self.tileSolidTop[644] = True
        self.tileSolidTop[632] = True
        self.tileSolidTop[640] = True
        self.tileSolidTop[559] = True
        self.tileSolidTop[414] = True
        self.tileSolidTop[359] = True
        self.tileSolidTop[358] = True
        self.tileSolidTop[285] = True
        self.tileSolidTop[286] = True
        self.tileSolidTop[582] = True
        self.tileSolidTop[555] = True
        self.tileSolidTop[538] = True
        self.tileSolidTop[533] = True
        self.tileSolidTop[532] = True
        self.tileSolidTop[394] = True
        self.tileSolidTop[393] = True
        self.tileSolidTop[392] = True
        self.tileSolidTop[391] = True
        self.tileSolidTop[339] = True
        self.tileSolidTop[310] = True
        self.tileSolidTop[299] = True
        self.tileSolidTop[298] = True
        self.tileSolidTop[629] = True
        self.tileSolidTop[619] = True
        self.tileSolidTop[556] = True
        self.tileSolidTop[544] = True
        self.tileSolidTop[364] = True
        self.tileSolidTop[363] = True
        self.tileSolidTop[362] = True
        self.tileSolidTop[361] = True
        self.tileSolidTop[710] = True
        self.tileTable[280] = True
        self.tileTable[275] = True
        self.tileTable[276] = True
        self.tileTable[277] = True
        self.tileTable[278] = True
        self.tileTable[279] = True
        self.tileTable[281] = True
        self.tileTable[605] = True
        self.tileTable[604] = True
        self.tileTable[603] = True
        self.tileTable[602] = True
        self.tileTable[601] = True
        self.tileTable[599] = True
        self.tileTable[600] = True
        self.tileTable[612] = True
        self.tileTable[611] = True
        self.tileTable[610] = True
        self.tileTable[609] = True
        self.tileTable[608] = True
        self.tileTable[606] = True
        self.tileTable[607] = True
        self.tileTable[558] = True
        self.tileTable[554] = True
        self.tileTable[553] = True
        self.tileTable[551] = True
        self.tileTable[550] = True
        self.tileTable[542] = True
        self.tileTable[413] = True
        self.tileTable[309] = True
        self.tileTable[297] = True
        self.tileTable[296] = True
        self.tileTable[645] = True
        self.tileTable[643] = True
        self.tileTable[644] = True
        self.tileTable[632] = True
        self.tileTable[640] = True
        self.tileTable[559] = True
        self.tileTable[414] = True
        self.tileTable[359] = True
        self.tileTable[358] = True
        self.tileTable[285] = True
        self.tileTable[286] = True
        self.tileTable[582] = True
        self.tileTable[555] = True
        self.tileTable[538] = True
        self.tileTable[533] = True
        self.tileTable[532] = True
        self.tileTable[394] = True
        self.tileTable[393] = True
        self.tileTable[392] = True
        self.tileTable[391] = True
        self.tileTable[339] = True
        self.tileTable[310] = True
        self.tileTable[299] = True
        self.tileTable[298] = True
        self.tileTable[629] = True
        self.tileTable[619] = True
        self.tileTable[556] = True
        self.tileTable[544] = True
        self.tileTable[364] = True
        self.tileTable[363] = True
        self.tileTable[362] = True
        self.tileTable[361] = True
        self.tileTable[710] = True
        self.tileBrick[1] = True
        self.tileBrick[54] = True
        self.tileBrick[118] = True
        self.tileBrick[119] = True
        self.tileBrick[120] = True
        self.tileBrick[121] = True
        self.tileBrick[122] = True
        self.tileBrick[140] = True
        self.tileBrick[148] = True
        self.tileBrick[150] = True
        self.tileBrick[151] = True
        self.tileBrick[152] = True
        self.tileBrick[30] = True
        self.tileBrick[38] = True
        self.tileBrick[39] = True
        self.tileBrick[41] = True
        self.tileBrick[43] = True
        self.tileBrick[44] = True
        self.tileBrick[481] = True
        self.tileBrick[482] = True
        self.tileBrick[483] = True
        self.tileBrick[45] = True
        self.tileBrick[46] = True
        self.tileBrick[47] = True
        self.tileBrick[75] = True
        self.tileBrick[76] = True
        self.tileBrick[160] = True
        self.tileBrick[2] = True
        self.tileBrick[199] = True
        self.tileBrick[23] = True
        self.tileBrick[60] = True
        self.tileBrick[70] = True
        self.tileBrick[109] = True
        self.tileBrick[53] = True
        self.tileBrick[57] = True
        self.tileBrick[116] = True
        self.tileBrick[234] = True
        self.tileBrick[112] = True
        self.tileBrick[147] = True
        self.tileBrick[153] = True
        self.tileBrick[154] = True
        self.tileBrick[155] = True
        self.tileBrick[156] = True
        self.tileBrick[157] = True
        self.tileBrick[158] = True
        self.tileBrick[159] = True
        self.tileBrick[273] = True
        self.tileBrick[274] = True
        self.tileMergeDirt[202] = True
        self.tileBrick[202] = True
        self.tileSolid[202] = True
        self.tileBlockLight[202] = True
        self.tileMergeDirt[498] = True
        self.tileBrick[161] = True
        self.tileBlockLight[161] = True
        self.tileBlockLight[163] = True
        self.tileBlockLight[164] = True
        self.tileSolid[188] = True
        self.tileBlockLight[188] = True
        self.tileBrick[188] = True
        self.tileMergeDirt[188] = True
        self.tileBrick[179] = True
        self.tileSolid[179] = True
        self.tileBlockLight[179] = True
        self.tileMoss[179] = True
        self.tileBrick[381] = True
        self.tileSolid[381] = True
        self.tileBlockLight[381] = True
        self.tileMoss[381] = True
        self.tileBrick[534] = True
        self.tileSolid[534] = True
        self.tileBlockLight[534] = True
        self.tileMoss[534] = True
        self.tileBrick[536] = True
        self.tileSolid[536] = True
        self.tileBlockLight[536] = True
        self.tileMoss[536] = True
        self.tileBrick[539] = True
        self.tileSolid[539] = True
        self.tileBlockLight[539] = True
        self.tileMoss[539] = True
        self.tileBrick[625] = True
        self.tileSolid[625] = True
        self.tileBlockLight[625] = True
        self.tileMoss[625] = True
        self.tileBrick[627] = True
        self.tileSolid[627] = True
        self.tileBlockLight[627] = True
        self.tileMoss[627] = True
        self.tileBrick[180] = True
        self.tileSolid[180] = True
        self.tileBlockLight[180] = True
        self.tileMoss[180] = True
        self.tileBrick[181] = True
        self.tileSolid[181] = True
        self.tileBlockLight[181] = True
        self.tileMoss[181] = True
        self.tileBrick[182] = True
        self.tileSolid[182] = True
        self.tileBlockLight[182] = True
        self.tileMoss[182] = True
        self.tileBrick[183] = True
        self.tileSolid[183] = True
        self.tileBlockLight[183] = True
        self.tileMoss[183] = True
        self.tileBrick[512] = True
        self.tileSolid[512] = True
        self.tileBlockLight[512] = True
        self.tileBrick[513] = True
        self.tileSolid[513] = True
        self.tileBlockLight[513] = True
        self.tileBrick[514] = True
        self.tileSolid[514] = True
        self.tileBlockLight[514] = True
        self.tileBrick[515] = True
        self.tileSolid[515] = True
        self.tileBlockLight[515] = True
        self.tileBrick[516] = True
        self.tileSolid[516] = True
        self.tileBlockLight[516] = True
        self.tileBrick[517] = True
        self.tileSolid[517] = True
        self.tileBlockLight[517] = True
        self.tileLighted[517] = True
        self.tileBrick[687] = True
        self.tileSolid[687] = True
        self.tileBlockLight[687] = True
        self.tileLighted[687] = True
        self.tileBrick[535] = True
        self.tileSolid[535] = True
        self.tileBlockLight[535] = True
        self.tileLighted[535] = True
        self.tileBrick[689] = True
        self.tileSolid[689] = True
        self.tileBlockLight[689] = True
        self.tileLighted[689] = True
        self.tileBrick[537] = True
        self.tileSolid[537] = True
        self.tileBlockLight[537] = True
        self.tileLighted[537] = True
        self.tileBrick[690] = True
        self.tileSolid[690] = True
        self.tileBlockLight[690] = True
        self.tileLighted[690] = True
        self.tileBrick[540] = True
        self.tileSolid[540] = True
        self.tileBlockLight[540] = True
        self.tileLighted[540] = True
        self.tileBrick[688] = True
        self.tileSolid[688] = True
        self.tileBlockLight[688] = True
        self.tileLighted[688] = True
        self.tileBrick[626] = True
        self.tileSolid[626] = True
        self.tileBlockLight[626] = True
        self.tileLighted[626] = True
        self.tileBrick[691] = True
        self.tileSolid[691] = True
        self.tileBlockLight[691] = True
        self.tileLighted[691] = True
        self.tileBrick[628] = True
        self.tileSolid[628] = True
        self.tileBlockLight[628] = True
        self.tileLighted[628] = True
        self.tileBrick[692] = True
        self.tileSolid[692] = True
        self.tileBlockLight[692] = True
        self.tileLighted[692] = True
        self.tileLighted[592] = True
        self.tileLighted[656] = True
        self.tileLighted[701] = True
        self.tileLighted[356] = True
        self.tileLighted[663] = True
        self.tileMergeDirt[177] = True
        self.tileMergeDirt[190] = True
        self.tileSolid[196] = True
        self.tileSolid[197] = True
        self.tileMergeDirt[197] = True
        self.tileBlockLight[197] = True
        self.tileNoSunLight[197] = True
        self.tileBrick[175] = True
        self.tileSolid[175] = True
        self.tileBlockLight[175] = True
        self.tileBrick[176] = True
        self.tileSolid[176] = True
        self.tileBlockLight[176] = True
        self.tileBrick[177] = True
        self.tileSolid[177] = True
        self.tileBlockLight[177] = True
        self.tileBrick[225] = True
        self.tileBrick[229] = True
        self.tileShine[221] = 925
        self.tileShine[222] = 875
        self.tileShine[223] = 825
        self.tileShine2[221] = True
        self.tileShine2[222] = True
        self.tileShine2[223] = True
        self.tileMergeDirt[175] = True
        self.tileMergeDirt[176] = True
        self.tileMergeDirt[177] = True
        self.tileMergeDirt[208] = True
        self.tileBrick[162] = True
        self.tileSolid[162] = True
        self.tileBlockLight[162] = False
        self.tileBrick[163] = True
        self.tileSolid[163] = True
        self.tileBrick[164] = True
        self.tileSolid[164] = True
        self.tileShine2[6] = True
        self.tileShine2[7] = True
        self.tileShine2[8] = True
        self.tileShine2[9] = True
        self.tileShine2[166] = True
        self.tileShine2[167] = True
        self.tileShine2[168] = True
        self.tileShine2[169] = True
        self.tileShine2[12] = True
        self.tileShine2[21] = True
        self.tileShine2[467] = True
        self.tileShine2[441] = True
        self.tileShine2[468] = True
        self.tileShine2[22] = True
        self.tileShine2[25] = True
        self.tileShine2[45] = True
        self.tileShine2[46] = True
        self.tileShine2[47] = True
        self.tileShine2[63] = True
        self.tileShine2[64] = True
        self.tileShine2[65] = True
        self.tileShine2[66] = True
        self.tileShine2[67] = True
        self.tileShine2[68] = True
        self.tileShine2[566] = True
        self.tileShine2[107] = True
        self.tileShine2[108] = True
        self.tileShine2[111] = True
        self.tileShine2[121] = True
        self.tileShine2[122] = True
        self.tileShine2[117] = True
        self.tileShine2[211] = True
        self.tileShine2[682] = True
        self.tileShine2[681] = True
        self.tileShine2[680] = True
        self.tileShine2[685] = True
        self.tileShine2[686] = True
        self.tileShine[129] = 300
        self.tileNoFail[81] = True
        self.tileCracked[481] = True
        self.tileCracked[482] = True
        self.tileCracked[483] = True
        self.tileNoFail[481] = True
        self.tileNoFail[482] = True
        self.tileNoFail[483] = True
        self.tileNoFail[330] = True
        self.tileNoFail[331] = True
        self.tileNoFail[332] = True
        self.tileNoFail[333] = True
        self.tileNoFail[254] = True
        self.tileNoFail[324] = True
        self.tileNoFail[129] = True
        self.tileNoFail[192] = True
        self.tileHammer[26] = True
        self.tileHammer[695] = True
        self.tileHammer[31] = True
        self.tileHammer[696] = True
        self.tileAxe[5] = True
        self.tileAxe[72] = True
        self.tileAxe[80] = True
        self.tileAxe[488] = True
        self.tileAxe[704] = True
        self.tileAxe[323] = True
        self.tileAxe[596] = True
        self.tileAxe[616] = True
        self.tileAxe[634] = True
        self.tileAxe[589] = True
        self.tileAxe[584] = True
        self.tileAxe[588] = True
        self.tileAxe[586] = True
        self.tileAxe[587] = True
        self.tileAxe[585] = True
        self.tileAxe[583] = True
        self.tileBrick[59] = True
        self.tileBrick[234] = True
        self.tileSolid[234] = True
        self.tileMergeDirt[234] = True
        self.tileSand[53] = True
        self.tileSand[112] = True
        self.tileSand[116] = True
        self.tileSand[234] = True
        self.tileFrameImportant[630] = True
        self.tileLavaDeath[630] = True
        self.tileNoSunLight[630] = True
        self.tileFrameImportant[631] = True
        self.tileLavaDeath[631] = True
        self.tileNoSunLight[631] = True
        self.tileFrameImportant[571] = True
        self.tileLavaDeath[571] = True
        self.tileFrameImportant[579] = True
        self.tileLavaDeath[579] = True
        self.tileFrameImportant[591] = True
        self.tileLavaDeath[591] = True
        self.tileFrameImportant[592] = True
        self.tileLavaDeath[592] = False
        self.tileFrameImportant[538] = True
        self.tileLavaDeath[538] = True
        self.tileFrameImportant[544] = True
        self.tileLavaDeath[544] = True
        self.tileFrameImportant[629] = True
        self.tileLavaDeath[629] = True
        self.tileFrameImportant[550] = True
        self.tileLavaDeath[550] = True
        self.tileFrameImportant[551] = True
        self.tileLavaDeath[551] = True
        self.tileFrameImportant[533] = True
        self.tileLavaDeath[533] = True
        self.tileFrameImportant[553] = True
        self.tileLavaDeath[553] = True
        self.tileFrameImportant[554] = True
        self.tileLavaDeath[554] = True
        self.tileFrameImportant[555] = True
        self.tileLavaDeath[555] = True
        self.tileFrameImportant[556] = True
        self.tileLavaDeath[556] = True
        self.tileFrameImportant[558] = True
        self.tileLavaDeath[558] = True
        self.tileFrameImportant[559] = True
        self.tileLavaDeath[559] = True
        self.tileFrameImportant[599] = True
        self.tileLavaDeath[599] = True
        self.tileFrameImportant[600] = True
        self.tileLavaDeath[600] = True
        self.tileFrameImportant[601] = True
        self.tileLavaDeath[601] = True
        self.tileFrameImportant[602] = True
        self.tileLavaDeath[602] = True
        self.tileFrameImportant[603] = True
        self.tileLavaDeath[603] = True
        self.tileFrameImportant[604] = True
        self.tileLavaDeath[604] = True
        self.tileFrameImportant[605] = True
        self.tileLavaDeath[605] = True
        self.tileFrameImportant[606] = True
        self.tileLavaDeath[606] = True
        self.tileFrameImportant[607] = True
        self.tileLavaDeath[607] = True
        self.tileFrameImportant[608] = True
        self.tileLavaDeath[608] = True
        self.tileFrameImportant[609] = True
        self.tileLavaDeath[609] = True
        self.tileFrameImportant[610] = True
        self.tileLavaDeath[610] = True
        self.tileFrameImportant[611] = True
        self.tileLavaDeath[611] = True
        self.tileFrameImportant[612] = True
        self.tileLavaDeath[612] = True
        self.tileFrameImportant[632] = True
        self.tileLavaDeath[632] = True
        self.tileFrameImportant[640] = True
        self.tileLavaDeath[640] = True
        self.tileFrameImportant[643] = True
        self.tileLavaDeath[643] = True
        self.tileFrameImportant[644] = True
        self.tileLavaDeath[644] = True
        self.tileFrameImportant[645] = True
        self.tileLavaDeath[645] = True
        self.tileFrameImportant[710] = True
        self.tileLavaDeath[710] = True
        self.tileFrameImportant[568] = True
        self.tileNoAttach[568] = True
        self.tileLavaDeath[568] = True
        self.tileLighted[568] = True
        self.tileFrameImportant[569] = True
        self.tileNoAttach[569] = True
        self.tileLavaDeath[569] = True
        self.tileLighted[569] = True
        self.tileFrameImportant[570] = True
        self.tileNoAttach[570] = True
        self.tileLavaDeath[570] = True
        self.tileLighted[570] = True
        self.tileFrameImportant[580] = True
        self.tileNoAttach[580] = True
        self.tileLavaDeath[580] = True
        self.tileLighted[580] = True
        self.tileFrameImportant[582] = True
        self.tileLavaDeath[582] = True
        self.tileLighted[582] = True
        self.tileFrameImportant[619] = True
        self.tileLavaDeath[619] = True
        self.tileLighted[619] = True
        self.tileFrameImportant[620] = True
        self.tileNoAttach[620] = True
        self.tileLavaDeath[620] = True
        self.tileLighted[620] = True
        self.tileFrameImportant[572] = True
        self.tileNoAttach[572] = True
        self.tileLavaDeath[572] = True
        self.tileLighted[572] = True
        self.tileFrameImportant[560] = True
        self.tileLavaDeath[560] = True
        self.tileFrameImportant[564] = True
        self.tileNoAttach[564] = True
        self.tileLavaDeath[564] = True
        self.tileLighted[564] = True
        self.tileFrameImportant[567] = True
        self.tileLavaDeath[567] = True
        self.tileFrameImportant[565] = True
        self.tileNoAttach[565] = True
        self.tileLavaDeath[565] = True
        self.tileFrameImportant[593] = True
        self.tileNoAttach[593] = True
        self.tileLavaDeath[593] = False
        self.tileLighted[593] = True
        self.tileFrameImportant[594] = True
        self.tileNoAttach[594] = True
        self.tileLavaDeath[594] = False
        self.tileLighted[594] = True
        self.tileLighted[548] = True
        self.tileLighted[613] = True
        self.tileLighted[614] = True
        self.tileFrameImportant[654] = True
        self.tileCut[654] = True
        self.tileNoFail[654] = True
        self.tileLavaDeath[654] = True
        self.tileFrameImportant[518] = True
        self.tileCut[518] = True
        self.tileNoFail[518] = True
        self.tileFrameImportant[519] = True
        self.tileCut[519] = True
        self.tileNoFail[519] = True
        self.tileLighted[519] = True
        self.tileFrameImportant[549] = True
        self.tileCut[549] = True
        self.tileNoFail[549] = True
        self.tileFrameImportant[529] = True
        self.tileCut[529] = True
        self.tileNoFail[529] = True
        self.tileLavaDeath[529] = True
        self.tileFrameImportant[637] = True
        self.tileCut[637] = True
        self.tileNoFail[637] = True
        self.tileLavaDeath[637] = False
        self.tileLighted[637] = True
        self.tileFrameImportant[530] = True
        self.tileNoFail[530] = True
        self.tileLavaDeath[530] = True
        self.tileFrameImportant[705] = True
        self.tileNoFail[705] = True
        self.tileLavaDeath[705] = True
        self.tileFrameImportant[233] = True
        self.tileFrameImportant[485] = True
        self.tileLighted[215] = True
        self.tileFrameImportant[227] = True
        self.tileFrameImportant[228] = True
        self.tileFrameImportant[231] = True
        self.tileCut[231] = True
        self.tileFrameImportant[216] = True
        self.tileFrameImportant[217] = True
        self.tileFrameImportant[218] = True
        self.tileFrameImportant[219] = True
        self.tileFrameImportant[642] = True
        self.tileFrameImportant[220] = True
        self.tileFrameImportant[338] = True
        self.tileFrameImportant[453] = True
        self.tileFrameImportant[456] = True
        self.tileFrameImportant[165] = True
        self.tileFrameImportant[209] = True
        self.tileFrameImportant[215] = True
        self.tileFrameImportant[210] = True
        self.tileFrameImportant[212] = True
        self.tileFrameImportant[207] = True
        self.tileFrameImportant[178] = True
        self.tileFrameImportant[184] = True
        self.tileFrameImportant[185] = True
        self.tileFrameImportant[186] = True
        self.tileFrameImportant[187] = True
        self.tileFrameImportant[173] = True
        self.tileFrameImportant[174] = True
        self.tileLighted[173] = True
        self.tileLighted[174] = True
        self.tileFrameImportant[139] = True
        self.tileLighted[160] = True
        self.tileLighted[149] = True
        self.tileFrameImportant[149] = True
        self.tileFrameImportant[142] = True
        self.tileFrameImportant[143] = True
        self.tileFrameImportant[144] = True
        self.tileStone[131] = True
        self.tileFrameImportant[136] = True
        self.tileFrameImportant[137] = True
        self.tileFrameImportant[138] = True
        self.tileFrameImportant[664] = True
        self.tileFrameImportant[665] = True
        self.tileFrameImportant[484] = True
        self.tileFrameImportant[711] = True
        self.tileFrameImportant[712] = True
        self.tileFrameImportant[713] = True
        self.tileFrameImportant[714] = True
        self.tileFrameImportant[715] = True
        self.tileFrameImportant[716] = True
        self.tileLavaDeath[484] = True
        self.tileNoFail[484] = True
        self.tileBlockLight[137] = True
        self.tileSolid[137] = True
        self.tileBlockLight[160] = True
        self.tileSolid[160] = True
        self.tileMergeDirt[160] = True
        self.tileBlockLight[161] = True
        self.tileSolid[161] = True
        self.tileBlockLight[145] = True
        self.tileSolid[145] = True
        self.tileMergeDirt[145] = True
        self.tileBlockLight[146] = True
        self.tileSolid[146] = True
        self.tileMergeDirt[146] = True
        self.tileBlockLight[147] = True
        self.tileSolid[147] = True
        self.tileBlockLight[148] = True
        self.tileSolid[148] = True
        self.tileMergeDirt[148] = True
        self.tileSolid[138] = True
        self.tileSolid[664] = True
        self.tileSolid[484] = True
        self.tileSolid[711] = True
        self.tileCut[484] = True
        self.tileCut[711] = True
        self.tileLighted[711] = True
        self.tileSolid[712] = True
        self.tileSolid[713] = True
        self.tileSolid[714] = True
        self.tileSolid[715] = True
        self.tileSolid[716] = True
        self.tileBlockLight[140] = True
        self.tileSolid[140] = True
        self.tileBlockLight[151] = True
        self.tileSolid[151] = True
        self.tileMergeDirt[151] = True
        self.tileBlockLight[152] = True
        self.tileSolid[152] = True
        self.tileMergeDirt[152] = True
        self.tileBlockLight[153] = True
        self.tileSolid[153] = True
        self.tileMergeDirt[153] = True
        self.tileBlockLight[154] = True
        self.tileSolid[154] = True
        self.tileMergeDirt[154] = True
        self.tileBlockLight[155] = True
        self.tileSolid[155] = True
        self.tileMergeDirt[155] = True
        self.tileBlockLight[156] = True
        self.tileSolid[156] = True
        self.tileMergeDirt[156] = True
        self.tileMergeDirt[150] = True
        self.tileBlockLight[157] = True
        self.tileSolid[157] = True
        self.tileMergeDirt[157] = True
        self.tileBlockLight[158] = True
        self.tileSolid[158] = True
        self.tileMergeDirt[158] = True
        self.tileBlockLight[159] = True
        self.tileSolid[159] = True
        self.tileMergeDirt[159] = True
        self.tileFrameImportant[320] = True
        self.tileFrameImportant[49] = True
        self.tileShine[22] = 1150
        self.tileShine[6] = 1150
        self.tileShine[7] = 1100
        self.tileShine[8] = 1000
        self.tileShine[9] = 1050
        self.tileShine[166] = 1125
        self.tileShine[167] = 1075
        self.tileShine[168] = 1025
        self.tileShine[169] = 975
        self.tileShine[617] = 400
        self.tileShine[178] = 500
        self.tileShine2[178] = True
        self.tileShine[12] = 300
        self.tileShine[21] = 1200
        self.tileShine[467] = 1200
        self.tileShine[441] = 1200
        self.tileShine[468] = 1200
        self.tileShine[63] = 900
        self.tileShine[64] = 900
        self.tileShine[65] = 900
        self.tileShine[66] = 900
        self.tileShine[67] = 900
        self.tileShine[68] = 900
        self.tileShine[566] = 900
        self.tileShine[45] = 1900
        self.tileShine[680] = 1900
        self.tileShine[46] = 2000
        self.tileShine[681] = 2000
        self.tileShine[47] = 2100
        self.tileShine[682] = 2100
        self.tileShine[122] = 1800
        self.tileShine[686] = 1800
        self.tileShine[121] = 1850
        self.tileShine[685] = 1850
        self.tileShine[125] = 600
        self.tileShine[109] = 9000
        self.tileShine[110] = 9000
        self.tileShine[116] = 9000
        self.tileShine[117] = 9000
        self.tileShine[118] = 8000
        self.tileShine[107] = 950
        self.tileShine[108] = 900
        self.tileShine[111] = 850
        self.tileShine[211] = 500
        self.tileLighted[699] = True
        self.tileLighted[4] = True
        self.tileLighted[17] = True
        self.tileLighted[133] = True
        self.tileLighted[31] = True
        self.tileLighted[696] = True
        self.tileLighted[33] = True
        self.tileLighted[34] = True
        self.tileLighted[35] = True
        self.tileLighted[37] = True
        self.tileLighted[42] = True
        self.tileLighted[49] = True
        self.tileLighted[58] = True
        self.tileLighted[61] = True
        self.tileLighted[703] = True
        self.tileLighted[70] = True
        self.tileLighted[71] = True
        self.tileLighted[72] = True
        self.tileLighted[76] = True
        self.tileLighted[684] = True
        self.tileLighted[77] = True
        self.tileLighted[19] = True
        self.tileLighted[22] = True
        self.tileLighted[26] = True
        self.tileLighted[695] = True
        self.tileLighted[83] = True
        self.tileLighted[84] = True
        self.tileLighted[92] = True
        self.tileLighted[93] = True
        self.tileLighted[95] = True
        self.tileLighted[98] = True
        self.tileLighted[100] = True
        self.tileLighted[109] = True
        self.tileLighted[125] = True
        self.tileLighted[126] = True
        self.tileLighted[129] = True
        self.tileLighted[140] = True
        self.tileLighted[270] = True
        self.tileLighted[271] = True
        self.tileLighted[581] = True
        self.tileLighted[660] = True
        self.tileLighted[578] = True
        self.tileMergeDirt[1] = True
        self.tileMergeDirt[6] = True
        self.tileMergeDirt[7] = True
        self.tileMergeDirt[8] = True
        self.tileMergeDirt[9] = True
        self.tileMergeDirt[166] = True
        self.tileMergeDirt[167] = True
        self.tileMergeDirt[168] = True
        self.tileMergeDirt[169] = True
        self.tileMergeDirt[22] = True
        self.tileMergeDirt[25] = True
        self.tileMergeDirt[30] = True
        self.tileMergeDirt[37] = True
        self.tileMergeDirt[38] = True
        self.tileMergeDirt[40] = True
        self.tileMergeDirt[53] = True
        self.tileMergeDirt[56] = True
        self.tileMergeDirt[107] = True
        self.tileMergeDirt[108] = True
        self.tileMergeDirt[111] = True
        self.tileMergeDirt[112] = True
        self.tileMergeDirt[116] = True
        self.tileMergeDirt[117] = True
        self.tileMergeDirt[123] = True
        self.tileMergeDirt[140] = True
        self.tileMergeDirt[39] = True
        self.tileMergeDirt[122] = True
        self.tileMergeDirt[121] = True
        self.tileMergeDirt[120] = True
        self.tileMergeDirt[119] = True
        self.tileMergeDirt[118] = True
        self.tileMergeDirt[47] = True
        self.tileMergeDirt[46] = True
        self.tileMergeDirt[45] = True
        self.tileMergeDirt[41] = True
        self.tileMergeDirt[43] = True
        self.tileMergeDirt[44] = True
        self.tileMergeDirt[481] = True
        self.tileMergeDirt[482] = True
        self.tileMergeDirt[483] = True
        self.tileFrameImportant[380] = True
        self.tileFrameImportant[201] = True
        self.tileFrameImportant[3] = True
        self.tileFrameImportant[4] = True
        self.tileFrameImportant[5] = True
        self.tileFrameImportant[10] = True
        self.tileFrameImportant[11] = True
        self.tileFrameImportant[12] = True
        self.tileFrameImportant[13] = True
        self.tileFrameImportant[14] = True
        self.tileFrameImportant[469] = True
        self.tileFrameImportant[486] = True
        self.tileFrameImportant[488] = True
        self.tileFrameImportant[704] = True
        self.tileFrameImportant[487] = True
        self.tileFrameImportant[489] = True
        self.tileFrameImportant[490] = True
        self.tileFrameImportant[15] = True
        self.tileFrameImportant[497] = True
        self.tileFrameImportant[16] = True
        self.tileFrameImportant[17] = True
        self.tileFrameImportant[18] = True
        self.tileFrameImportant[19] = True
        self.tileFrameImportant[20] = True
        self.tileFrameImportant[21] = True
        self.tileFrameImportant[467] = True
        self.tileFrameImportant[441] = True
        self.tileFrameImportant[468] = True
        self.tileFrameImportant[24] = True
        self.tileFrameImportant[26] = True
        self.tileFrameImportant[695] = True
        self.tileFrameImportant[27] = True
        self.tileFrameImportant[28] = True
        self.tileFrameImportant[29] = True
        self.tileFrameImportant[31] = True
        self.tileFrameImportant[696] = True
        self.tileFrameImportant[33] = True
        self.tileFrameImportant[34] = True
        self.tileFrameImportant[35] = True
        self.tileFrameImportant[42] = True
        self.tileFrameImportant[50] = True
        self.tileFrameImportant[707] = True
        self.tileFrameImportant[55] = True
        self.tileFrameImportant[61] = True
        self.tileFrameImportant[703] = True
        self.tileFrameImportant[71] = True
        self.tileFrameImportant[72] = True
        self.tileFrameImportant[73] = True
        self.tileFrameImportant[74] = True
        self.tileFrameImportant[77] = True
        self.tileFrameImportant[78] = True
        self.tileFrameImportant[79] = True
        self.tileFrameImportant[81] = True
        self.tileFrameImportant[82] = True
        self.tileFrameImportant[83] = True
        self.tileFrameImportant[84] = True
        self.tileFrameImportant[85] = True
        self.tileFrameImportant[86] = True
        self.tileFrameImportant[87] = True
        self.tileFrameImportant[88] = True
        self.tileFrameImportant[89] = True
        self.tileFrameImportant[90] = True
        self.tileFrameImportant[91] = True
        self.tileFrameImportant[92] = True
        self.tileFrameImportant[93] = True
        self.tileFrameImportant[94] = True
        self.tileFrameImportant[95] = True
        self.tileFrameImportant[96] = True
        self.tileFrameImportant[97] = True
        self.tileFrameImportant[98] = True
        self.tileFrameImportant[99] = True
        self.tileFrameImportant[101] = True
        self.tileFrameImportant[102] = True
        self.tileFrameImportant[103] = True
        self.tileFrameImportant[104] = True
        self.tileFrameImportant[105] = True
        self.tileFrameImportant[100] = True
        self.tileFrameImportant[106] = True
        self.tileFrameImportant[110] = True
        self.tileFrameImportant[113] = True
        self.tileFrameImportant[114] = True
        self.tileFrameImportant[125] = True
        self.tileFrameImportant[287] = True
        self.tileFrameImportant[126] = True
        self.tileFrameImportant[128] = True
        self.tileFrameImportant[129] = True
        self.tileFrameImportant[132] = True
        self.tileFrameImportant[133] = True
        self.tileFrameImportant[134] = True
        self.tileFrameImportant[135] = True
        self.tileFrameImportant[172] = True
        self.tileFrameImportant[319] = True
        self.tileFrameImportant[323] = True
        self.tileFrameImportant[335] = True
        self.tileFrameImportant[337] = True
        self.tileFrameImportant[349] = True
        self.tileFrameImportant[376] = True
        self.tileFrameImportant[378] = True
        self.tileFrameImportant[425] = True
        self.tileFrameImportant[465] = True
        self.tileFrameImportant[506] = True
        self.tileFrameImportant[510] = True
        self.tileFrameImportant[511] = True
        self.tileFrameImportant[531] = True
        self.tileFrameImportant[545] = True
        self.tileFrameImportant[547] = True
        self.tileFrameImportant[548] = True
        self.tileFrameImportant[552] = True
        self.tileFrameImportant[573] = True
        self.tileFrameImportant[613] = True
        self.tileFrameImportant[614] = True
        self.tileFrameImportant[621] = True
        self.tileFrameImportant[622] = True
        self.tileFrameImportant[623] = True
        self.tileFrameImportant[624] = True
        self.tileFrameImportant[700] = True
        self.tileFrameImportant[656] = True
        self.tileFrameImportant[701] = True
        self.tileFrameImportant[141] = True
        self.tileFrameImportant[270] = True
        self.tileFrameImportant[271] = True
        self.tileFrameImportant[581] = True
        self.tileFrameImportant[660] = True
        self.tileFrameImportant[314] = True
        self.tileFrameImportant[698] = True
        self.tileSolidTop[376] = True
        self.tileTable[376] = True
        self.tileTable[380] = True
        self.tileFrameImportant[583] = True
        self.tileFrameImportant[584] = True
        self.tileFrameImportant[585] = True
        self.tileFrameImportant[586] = True
        self.tileFrameImportant[587] = True
        self.tileFrameImportant[588] = True
        self.tileFrameImportant[589] = True
        self.tileFrameImportant[590] = True
        self.tileNoAttach[590] = True
        self.tileFrameImportant[595] = True
        self.tileNoAttach[595] = True
        self.tileFrameImportant[596] = True
        self.tileFrameImportant[615] = True
        self.tileNoAttach[615] = True
        self.tileFrameImportant[616] = True
        self.tileFrameImportant[634] = True
        self.tileCut[201] = True
        self.tileCut[3] = True
        self.tileCut[24] = True
        self.tileCut[28] = True
        self.tileCut[32] = True
        self.tileCut[51] = True
        self.tileCut[52] = True
        self.tileCut[61] = True
        self.tileCut[62] = True
        self.tileCut[69] = True
        self.tileCut[655] = True
        self.tileCut[71] = True
        self.tileCut[73] = True
        self.tileCut[74] = True
        self.tileCut[82] = True
        self.tileCut[83] = True
        self.tileCut[84] = True
        self.tileCut[110] = True
        self.tileCut[113] = True
        self.tileCut[115] = True
        self.tileCut[184] = True
        self.tileCut[205] = True
        self.tileCut[352] = True
        self.tileCut[382] = True
        self.tileCut[528] = True
        self.tileLighted[528] = True
        self.tileCut[636] = True
        self.tileCut[638] = True
        self.tileCut[444] = True
        self.tileCut[485] = True
        self.tileAlch[82] = True
        self.tileAlch[83] = True
        self.tileAlch[84] = True
        self.tileSolid[127] = True
        self.tileSolid[130] = True
        self.tileBlockLight[130] = True
        self.tileBlockLight[131] = True
        self.tileSolid[107] = True
        self.tileBlockLight[107] = True
        self.tileSolid[108] = True
        self.tileBlockLight[108] = True
        self.tileSolid[111] = True
        self.tileBlockLight[111] = True
        self.tileSolid[109] = True
        self.tileBlockLight[109] = True
        self.tileSolid[110] = False
        self.tileNoAttach[110] = True
        self.tileNoFail[110] = True
        self.tileSolid[112] = True
        self.tileBlockLight[112] = True
        self.tileSolid[116] = True
        self.tileBlockLight[116] = True
        self.tileBrick[117] = True
        self.tileBrick[25] = True
        self.tileBrick[203] = True
        self.tileSolid[117] = True
        self.tileBlockLight[117] = True
        self.tileSolid[123] = True
        self.tileBlockLight[123] = True
        self.tileNoFail[165] = True
        self.tileNoFail[184] = True
        self.tileNoFail[185] = True
        self.tileNoFail[186] = True
        self.tileNoFail[187] = True
        self.tileSolid[118] = True
        self.tileBlockLight[118] = True
        self.tileSolid[119] = True
        self.tileBlockLight[119] = True
        self.tileSolid[120] = True
        self.tileBlockLight[120] = True
        self.tileSolid[121] = True
        self.tileBlockLight[121] = True
        self.tileSolid[122] = True
        self.tileBlockLight[122] = True
        self.tileSolid[150] = True
        self.tileBlockLight[150] = True
        self.tileBlockLight[115] = True
        self.tileSolid[199] = True
        self.tileBlockLight[199] = True
        self.tileNoFail[162] = True
        self.tileSolid[0] = True
        self.tileBlockLight[0] = True
        self.tileSolid[1] = True
        self.tileBlockLight[1] = True
        self.tileSolid[2] = True
        self.tileBlockLight[2] = True
        self.tileSolid[3] = False
        self.tileNoAttach[3] = True
        self.tileNoFail[3] = True
        self.tileNoFail[201] = True
        self.tileSolid[4] = False
        self.tileNoAttach[4] = True
        self.tileNoFail[4] = True
        self.tileNoFail[24] = True
        self.tileSolid[5] = False
        self.tileSolid[6] = True
        self.tileBlockLight[6] = True
        self.tileSolid[7] = True
        self.tileBlockLight[7] = True
        self.tileSolid[8] = True
        self.tileBlockLight[8] = True
        self.tileSolid[9] = True
        self.tileBlockLight[9] = True
        self.tileSolid[166] = True
        self.tileBlockLight[166] = True
        self.tileSolid[167] = True
        self.tileBlockLight[167] = True
        self.tileSolid[168] = True
        self.tileBlockLight[168] = True
        self.tileSolid[169] = True
        self.tileBlockLight[169] = True
        self.tileBlockLight[10] = True
        self.tileSolid[10] = True
        self.tileNoAttach[10] = True
        self.tileBlockLight[10] = True
        self.tileSolid[11] = False
        self.tileSolidTop[19] = True
        self.tileSolid[19] = True
        self.tileSolid[22] = True
        self.tileSolid[23] = True
        self.tileSolid[25] = True
        self.tileSolid[30] = True
        self.tileNoFail[32] = True
        self.tileBlockLight[32] = True
        self.tileNoFail[352] = True
        self.tileBlockLight[352] = True
        self.tileSolid[37] = True
        self.tileBlockLight[37] = True
        self.tileSolid[38] = True
        self.tileBlockLight[38] = True
        self.tileSolid[39] = True
        self.tileBlockLight[39] = True
        self.tileSolid[40] = True
        self.tileBlockLight[40] = True
        self.tileSolid[41] = True
        self.tileBlockLight[41] = True
        self.tileSolid[43] = True
        self.tileBlockLight[43] = True
        self.tileSolid[44] = True
        self.tileBlockLight[44] = True
        self.tileSolid[481] = True
        self.tileBlockLight[481] = True
        self.tileSolid[482] = True
        self.tileBlockLight[482] = True
        self.tileSolid[483] = True
        self.tileBlockLight[483] = True
        self.tileSolid[634] = False
        self.tileFrameImportant[634] = True
        self.tileLavaDeath[634] = False
        self.tileBlockLight[634] = False
        self.tileLighted[634] = True
        self.tileLighted[20] = True
        self.tileSolid[45] = True
        self.tileBlockLight[45] = True
        self.tileSolid[46] = True
        self.tileBlockLight[46] = True
        self.tileSolid[47] = True
        self.tileBlockLight[47] = True
        self.tileSolid[48] = True
        self.tileSolid[53] = True
        self.tileBlockLight[53] = True
        self.tileSolid[54] = True
        self.tileBlockLight[52] = True
        self.tileBlockLight[205] = True
        self.tileSolid[56] = True
        self.tileBlockLight[56] = True
        self.tileSolid[57] = True
        self.tileBlockLight[57] = True
        self.tileSolid[58] = True
        self.tileBlockLight[58] = True
        self.tileBlockLight[382] = True
        self.tileSolid[59] = True
        self.tileBlockLight[59] = True
        self.tileSolid[60] = True
        self.tileBlockLight[60] = True
        self.tileSolid[63] = True
        self.tileBlockLight[63] = True
        self.tileStone[63] = True
        self.tileStone[130] = True
        self.tileSolid[64] = True
        self.tileBlockLight[64] = True
        self.tileStone[64] = True
        self.tileSolid[65] = True
        self.tileBlockLight[65] = True
        self.tileStone[65] = True
        self.tileSolid[66] = True
        self.tileBlockLight[66] = True
        self.tileStone[66] = True
        self.tileSolid[67] = True
        self.tileBlockLight[67] = True
        self.tileStone[67] = True
        self.tileSolid[68] = True
        self.tileBlockLight[68] = True
        self.tileStone[68] = True
        self.tileSolid[566] = True
        self.tileBlockLight[566] = True
        self.tileStone[566] = True
        self.tileSolid[75] = True
        self.tileBlockLight[75] = True
        self.tileBrick[633] = True
        self.tileSolid[633] = True
        self.tileBlockLight[633] = True
        self.tileLighted[633] = True
        self.tileSolid[76] = True
        self.tileBlockLight[76] = True
        self.tileSolid[70] = True
        self.tileBlockLight[70] = True
        self.tileSolid[661] = True
        self.tileBlockLight[661] = True
        self.tileBrick[661] = True
        self.tileSolid[662] = True
        self.tileBlockLight[662] = True
        self.tileBrick[662] = True
        self.tileNoFail[50] = True
        self.tileNoAttach[50] = True
        self.tileNoAttach[707] = True
        self.tileDungeon[41] = True
        self.tileDungeon[43] = True
        self.tileDungeon[44] = True
        self.tileDungeon[677] = True
        self.tileDungeon[678] = True
        self.tileDungeon[679] = True
        self.tileBlockLight[30] = True
        self.tileBlockLight[25] = True
        self.tileBlockLight[23] = True
        self.tileBlockLight[22] = True
        self.tileBlockLight[62] = True
        self.tileSolidTop[18] = True
        self.tileSolidTop[14] = True
        self.tileSolidTop[469] = True
        self.tileSolidTop[16] = True
        self.tileSolidTop[134] = True
        self.tileSolidTop[114] = True
        self.tileNoAttach[20] = True
        self.tileNoAttach[19] = True
        self.tileNoAttach[13] = True
        self.tileNoAttach[14] = True
        self.tileNoAttach[469] = True
        self.tileNoAttach[486] = True
        self.tileNoAttach[488] = True
        self.tileNoAttach[704] = True
        self.tileNoAttach[487] = True
        self.tileNoAttach[489] = True
        self.tileNoAttach[490] = True
        self.tileNoAttach[15] = True
        self.tileNoAttach[497] = True
        self.tileNoAttach[16] = True
        self.tileNoAttach[134] = True
        self.tileNoAttach[17] = True
        self.tileNoAttach[18] = True
        self.tileNoAttach[21] = True
        self.tileNoAttach[467] = True
        self.tileNoAttach[441] = True
        self.tileNoAttach[468] = True
        self.tileNoAttach[27] = True
        self.tileNoAttach[114] = True
        self.tileTable[14] = True
        self.tileTable[469] = True
        self.tileTable[18] = True
        self.tileTable[19] = True
        self.tileTable[114] = True
        self.tileNoAttach[86] = True
        self.tileNoAttach[87] = True
        self.tileNoAttach[88] = True
        self.tileNoAttach[89] = True
        self.tileNoAttach[90] = True
        self.tileTable[101] = True
        self.tileNoAttach[101] = True
        self.tileNoAttach[102] = True
        self.tileNoAttach[94] = True
        self.tileNoAttach[95] = True
        self.tileNoAttach[96] = True
        self.tileNoAttach[97] = True
        self.tileNoAttach[98] = True
        self.tileNoAttach[99] = True
        self.tileTable[87] = True
        self.tileTable[88] = True
        self.tileSolidTop[87] = True
        self.tileSolidTop[88] = True
        self.tileSolidTop[101] = True
        self.tileNoAttach[91] = True
        self.tileNoAttach[92] = True
        self.tileNoAttach[93] = True
        self.tileLighted[190] = True
        self.tileBlockLight[192] = True
        self.tileWaterDeath[215] = True
        self.tileWaterDeath[4] = True
        self.tileWaterDeath[51] = True
        self.tileWaterDeath[697] = True
        self.tileWaterDeath[93] = True
        self.tileWaterDeath[98] = True
        self.tileWaterDeath[552] = True
        self.tileLavaDeath[3] = True
        self.tileLavaDeath[5] = True
        self.tileLavaDeath[10] = True
        self.tileLavaDeath[11] = True
        self.tileLavaDeath[12] = True
        self.tileLavaDeath[13] = True
        self.tileLavaDeath[14] = True
        self.tileLavaDeath[469] = True
        self.tileLavaDeath[486] = True
        self.tileLavaDeath[488] = True
        self.tileLavaDeath[704] = True
        self.tileLavaDeath[487] = True
        self.tileLavaDeath[489] = True
        self.tileLavaDeath[490] = True
        self.tileLavaDeath[15] = True
        self.tileLavaDeath[497] = True
        self.tileLavaDeath[16] = True
        self.tileLavaDeath[17] = True
        self.tileLavaDeath[18] = True
        self.tileLavaDeath[19] = True
        self.tileLavaDeath[24] = True
        self.tileLavaDeath[27] = True
        self.tileLavaDeath[28] = True
        self.tileLavaDeath[29] = True
        self.tileLavaDeath[32] = True
        self.tileLavaDeath[33] = True
        self.tileLavaDeath[34] = True
        self.tileLavaDeath[35] = True
        self.tileLavaDeath[36] = True
        self.tileLavaDeath[42] = True
        self.tileLavaDeath[49] = True
        self.tileLavaDeath[50] = True
        self.tileLavaDeath[707] = True
        self.tileLavaDeath[51] = True
        self.tileLavaDeath[697] = True
        self.tileLavaDeath[52] = True
        self.tileLavaDeath[55] = True
        self.tileLavaDeath[61] = True
        self.tileLavaDeath[703] = True
        self.tileLavaDeath[62] = True
        self.tileLavaDeath[69] = True
        self.tileLavaDeath[655] = True
        self.tileLavaDeath[71] = True
        self.tileLavaDeath[72] = True
        self.tileLavaDeath[73] = True
        self.tileLavaDeath[74] = True
        self.tileLavaDeath[79] = True
        self.tileLavaDeath[80] = True
        self.tileLavaDeath[81] = True
        self.tileLavaDeath[86] = True
        self.tileLavaDeath[87] = True
        self.tileLavaDeath[88] = True
        self.tileLavaDeath[89] = True
        self.tileLavaDeath[90] = True
        self.tileLavaDeath[91] = True
        self.tileLavaDeath[92] = True
        self.tileLavaDeath[93] = True
        self.tileLavaDeath[94] = True
        self.tileLavaDeath[95] = True
        self.tileLavaDeath[96] = True
        self.tileLavaDeath[97] = True
        self.tileLavaDeath[98] = True
        self.tileLavaDeath[100] = True
        self.tileLavaDeath[101] = True
        self.tileLavaDeath[102] = True
        self.tileLavaDeath[103] = True
        self.tileLavaDeath[104] = True
        self.tileLavaDeath[106] = True
        self.tileLavaDeath[110] = True
        self.tileLavaDeath[113] = True
        self.tileLavaDeath[115] = True
        self.tileLavaDeath[125] = True
        self.tileLavaDeath[126] = True
        self.tileLavaDeath[128] = True
        self.tileLavaDeath[149] = True
        self.tileLavaDeath[172] = True
        self.tileLavaDeath[173] = True
        self.tileLavaDeath[174] = True
        self.tileLavaDeath[184] = True
        self.tileLavaDeath[201] = True
        self.tileLavaDeath[205] = True
        self.tileLavaDeath[201] = True
        self.tileLavaDeath[209] = True
        self.tileLavaDeath[210] = True
        self.tileLavaDeath[212] = True
        self.tileLavaDeath[213] = True
        self.tileLavaDeath[353] = True
        self.tileLavaDeath[214] = False
        self.tileLavaDeath[215] = True
        self.tileLavaDeath[216] = True
        self.tileLavaDeath[217] = True
        self.tileLavaDeath[218] = True
        self.tileLavaDeath[219] = True
        self.tileLavaDeath[642] = True
        self.tileLavaDeath[220] = True
        self.tileLavaDeath[227] = True
        self.tileLavaDeath[228] = True
        self.tileLavaDeath[233] = True
        self.tileLavaDeath[236] = True
        self.tileLavaDeath[702] = True
        self.tileLavaDeath[238] = True
        self.tileLavaDeath[240] = True
        self.tileLavaDeath[241] = True
        self.tileLavaDeath[242] = True
        self.tileLavaDeath[243] = True
        self.tileLavaDeath[244] = True
        self.tileLavaDeath[245] = True
        self.tileLavaDeath[246] = True
        self.tileLavaDeath[247] = True
        self.tileLavaDeath[254] = True
        self.tileLavaDeath[269] = True
        self.tileLavaDeath[270] = True
        self.tileLavaDeath[271] = True
        self.tileLavaDeath[581] = True
        self.tileLavaDeath[698] = True
        self.tileLavaDeath[660] = True
        self.tileLavaDeath[275] = True
        self.tileLavaDeath[413] = True
        self.tileLavaDeath[276] = True
        self.tileLavaDeath[277] = True
        self.tileLavaDeath[278] = True
        self.tileLavaDeath[279] = True
        self.tileLavaDeath[280] = True
        self.tileLavaDeath[281] = True
        self.tileLavaDeath[282] = True
        self.tileLavaDeath[283] = True
        self.tileLavaDeath[285] = True
        self.tileLavaDeath[286] = True
        self.tileLavaDeath[287] = True
        self.tileLavaDeath[288] = True
        self.tileLavaDeath[289] = True
        self.tileLavaDeath[290] = True
        self.tileLavaDeath[291] = True
        self.tileLavaDeath[292] = True
        self.tileLavaDeath[293] = True
        self.tileLavaDeath[294] = True
        self.tileLavaDeath[295] = True
        self.tileLavaDeath[296] = True
        self.tileLavaDeath[297] = True
        self.tileLavaDeath[298] = True
        self.tileLavaDeath[299] = True
        self.tileLavaDeath[300] = True
        self.tileLavaDeath[301] = True
        self.tileLavaDeath[302] = True
        self.tileLavaDeath[303] = True
        self.tileLavaDeath[304] = True
        self.tileLavaDeath[305] = True
        self.tileLavaDeath[306] = True
        self.tileLavaDeath[307] = True
        self.tileLavaDeath[308] = True
        self.tileLavaDeath[309] = True
        self.tileLavaDeath[310] = True
        self.tileLavaDeath[532] = True
        self.tileLavaDeath[316] = True
        self.tileLavaDeath[317] = True
        self.tileLavaDeath[318] = True
        self.tileLavaDeath[319] = True
        self.tileLavaDeath[354] = True
        self.tileLavaDeath[355] = True
        self.tileLavaDeath[699] = True
        self.tileLavaDeath[499] = True
        self.tileLavaDeath[323] = True
        self.tileLavaDeath[335] = True
        self.tileLavaDeath[338] = True
        self.tileLavaDeath[339] = True
        self.tileLavaDeath[528] = True
        self.tileLavaDeath[636] = True
        self.tileLavaDeath[638] = False
        self.tileLavaDeath[352] = True
        self.tileLavaDeath[382] = True
        self.tileLavaDeath[425] = True
        self.tileLavaDeath[453] = True
        self.tileLavaDeath[456] = True
        self.tileLavaDeath[463] = True
        self.tileLavaDeath[464] = True
        self.tileLavaDeath[465] = True
        self.tileLavaDeath[485] = True
        self.tileLavaDeath[511] = True
        self.tileLavaDeath[510] = True
        self.tileLavaDeath[547] = True
        self.tileLavaDeath[548] = True
        self.tileLavaDeath[552] = True
        self.tileLavaDeath[573] = True
        self.tileLavaDeath[621] = True
        self.tileLavaDeath[622] = True
        self.tileLavaDeath[623] = True
        self.tileLavaDeath[624] = True
        self.tileLavaDeath[700] = True
        self.tileLavaDeath[656] = True
        self.tileLavaDeath[701] = True
        self.tileLighted[316] = True
        self.tileLighted[317] = True
        self.tileLighted[318] = True
        self.tileFrameImportant[493] = True
        self.tileLavaDeath[493] = True
        for j in range(0, self.TileID_Count):
            if self.tileLavaDeath[j]:
                self.tileObsidianKill[j] = True
        self.tileObsidianKill[88] = False
        self.tileObsidianKill[546] = True
        self.tileObsidianKill[77] = True
        self.tileObsidianKill[78] = True
        self.tileObsidianKill[82] = True
        self.tileObsidianKill[83] = True
        self.tileObsidianKill[84] = True
        self.tileObsidianKill[85] = True
        self.tileObsidianKill[105] = True
        self.tileObsidianKill[129] = True
        self.tileObsidianKill[132] = True
        self.tileObsidianKill[133] = True
        self.tileObsidianKill[134] = True
        self.tileObsidianKill[135] = True
        self.tileObsidianKill[136] = True
        self.tileObsidianKill[139] = True
        self.tileObsidianKill[165] = True
        self.tileObsidianKill[178] = True
        self.tileObsidianKill[185] = True
        self.tileObsidianKill[186] = True
        self.tileObsidianKill[187] = True
        self.tileObsidianKill[231] = True
        self.tileObsidianKill[337] = True
        self.tileObsidianKill[349] = True
        self.tileObsidianKill[506] = True
        self.tileObsidianKill[314] = True
        self.tileSolid[384] = True
        self.tileBlockLight[384] = True
        self.tileNoFail[384] = True
        self.tileFrameImportant[395] = True
        self.tileLavaDeath[395] = True
        self.tileFrameImportant[520] = True
        self.tileLavaDeath[520] = True
        self.tileLavaDeath[471] = True
        self.tileFrameImportant[405] = True
        self.tileLavaDeath[405] = True
        self.tileSolidTop[405] = True
        self.tileTable[405] = True
        self.tileLighted[405] = True
        self.tileWaterDeath[405] = True
        self.tileFrameImportant[406] = True
        self.tileLavaDeath[406] = True
        self.tileFrameImportant[452] = True
        self.tileLavaDeath[452] = True
        self.tileFrameImportant[411] = True
        self.tileLavaDeath[411] = False
        self.tileFrameImportant[457] = True
        self.tileLavaDeath[457] = True
        self.tileFrameImportant[462] = True
        self.tileFrameImportant[454] = True
        self.tileLavaDeath[454] = True
        self.tileCut[454] = True
        self.tileFrameImportant[494] = True
        self.tileLavaDeath[494] = True
        self.tileFrameImportant[455] = True
        self.tileFrameImportant[412] = True
        for _ in range(0, self.WallID_Count):
            pass
            # blendType = WallID.Sets.BlendType[k];
            # if (blendType < 0 || blendType >= WallID.Count)
            # {
            #     Main.wallBlend[k] = k;
            # }
            # else
            # {
            #     Main.wallBlend[k] = blendType;
            # }
        self.tileNoFail[24] = True
        self.tileNoFail[3] = True
        self.tileNoFail[52] = True
        self.tileNoFail[62] = True
        self.tileNoFail[32] = True
        self.tileNoFail[61] = True
        self.tileNoFail[69] = True
        self.tileNoFail[655] = True
        self.tileNoFail[73] = True
        self.tileNoFail[74] = True
        self.tileNoFail[82] = True
        self.tileNoFail[83] = True
        self.tileNoFail[84] = True
        self.tileNoFail[110] = True
        self.tileNoFail[113] = True
        self.tileNoFail[115] = True
        self.tileNoFail[165] = True
        self.tileNoFail[184] = True
        self.tileNoFail[201] = True
        self.tileNoFail[205] = True
        self.tileNoFail[227] = True
        self.tileNoFail[233] = True
        self.tileNoFail[624] = True
        self.tileNoFail[700] = True
        self.tileNoFail[352] = True
        self.tileNoFail[382] = True
        self.tileNoFail[528] = True
        self.tileNoFail[485] = True
        self.tileNoFail[636] = True
        self.tileNoFail[638] = True
        self.tileNoFail[656] = True
        self.tileNoFail[701] = True
        self.tileLighted[638] = True
        self.tileFrameImportant[387] = True
        self.tileSolid[387] = True
        self.tileBlockLight[387] = True
        self.tileNoAttach[387] = True
        self.tileLavaDeath[387] = True
        self.tileFrameImportant[386] = True
        self.tileLavaDeath[386] = True
        self.tileNoSunLight[386] = True
        self.tileFrameImportant[388] = True
        self.tileSolid[388] = True
        self.tileBlockLight[388] = True
        self.tileNoAttach[388] = True
        self.tileLavaDeath[388] = True
        self.tileFrameImportant[389] = True
        self.tileLavaDeath[389] = True
        self.tileNoSunLight[389] = True
        for ax in range(0, self.TileID_Count):
            if self.tileSolid[ax]:
                self.tileNoSunLight[ax] = True
            self.tileFrame[ax] = 0
            self.tileFrameCounter[ax] = 0
        self.tileNoSunLight[546] = False
        self.tileNoSunLight[379] = False
        self.tileNoSunLight[54] = False
        self.tileNoSunLight[328] = False
        self.tileNoSunLight[459] = False
        self.tileNoSunLight[19] = False
        self.tileNoSunLight[11] = True
        self.tileNoSunLight[189] = False
        self.tileNoSunLight[196] = False
        self.tileNoSunLight[48] = False
        self.tileNoSunLight[232] = False
        self.tileNoSunLight[460] = False
        self.tileNoSunLight[541] = False
        self.tileNoSunLight[388] = False
        self.tileNoSunLight[748] = False
        self.tileNoSunLight[750] = False
        self.AddEchoFurnitureTile(647)
        self.AddEchoFurnitureTile(648)
        self.AddEchoFurnitureTile(706)
        self.AddEchoFurnitureTile(650)
        self.AddEchoFurnitureTile(649)
        self.AddEchoFurnitureTile(652)
        self.AddEchoFurnitureTile(651)
        self.AddEchoFurnitureTile(693)
        self.AddEchoFurnitureTile(694)
        self.tileFrameImportant[653] = True
        self.tileFrameImportant[723] = True
        self.tileFrameImportant[724] = True

    def AddEchoFurnitureTile(self, tileId: int) -> None:
        self.tileFrameImportant[tileId] = True
        self.tileNoFail[tileId] = True
        self.tileObsidianKill[tileId] = True

    def SetTileValue(self) -> None:
        self.tileOreFinderPriority[28] = 100
        self.tileOreFinderPriority[407] = 150
        self.tileOreFinderPriority[404] = 150
        self.tileOreFinderPriority[7] = 200
        self.tileOreFinderPriority[166] = 210
        self.tileOreFinderPriority[6] = 220
        self.tileOreFinderPriority[167] = 230
        self.tileOreFinderPriority[9] = 240
        self.tileOreFinderPriority[168] = 250
        self.tileOreFinderPriority[8] = 260
        self.tileOreFinderPriority[169] = 270
        self.tileOreFinderPriority[22] = 300
        self.tileOreFinderPriority[204] = 310
        self.tileOreFinderPriority[37] = 400
        self.tileOreFinderPriority[21] = 500
        self.tileOreFinderPriority[467] = 500
        self.tileOreFinderPriority[441] = 500
        self.tileOreFinderPriority[468] = 500
        self.tileOreFinderPriority[12] = 550
        self.tileOreFinderPriority[665] = 550
        self.tileOreFinderPriority[639] = 550
        self.tileOreFinderPriority[107] = 600
        self.tileOreFinderPriority[221] = 610
        self.tileOreFinderPriority[108] = 620
        self.tileOreFinderPriority[222] = 630
        self.tileOreFinderPriority[111] = 640
        self.tileOreFinderPriority[223] = 650
        self.tileOreFinderPriority[129] = 675
        self.tileOreFinderPriority[211] = 700
        self.tileOreFinderPriority[227] = 750
        self.tileOreFinderPriority[656] = 760
        self.tileOreFinderPriority[701] = 760
        self.tileOreFinderPriority[751] = 770
        self.tileOreFinderPriority[752] = 770
        self.tileOreFinderPriority[236] = 810
        self.tileOreFinderPriority[702] = 810

    def SetupTileMerge(self) -> None:
        pass

    def AnimateTiles_CritterCages(self) -> None:
        pass



from terrex.id import MessageID
from terrex.net.streamer import Reader, Writer
from terrex.packet.base import ServerPacket


class ShopOverride(ServerPacket):
    id = MessageID.ShopOverride

    def __init__(
        self,
        slot: int = 0,
        item_type: int = 0,
        stack: int = 0,
        prefix: int = 0,
        value: int = 0,
        buy_once: bool = False,
    ):
        self.slot = slot
        self.item_type = item_type
        self.stack = stack
        self.prefix = prefix
        self.value = value
        self.buy_once = buy_once

    def read(self, reader: Reader):
        self.slot = reader.read_byte()
        self.item_type = reader.read_short()
        self.stack = reader.read_short()
        self.prefix = reader.read_byte()
        self.value = reader.read_int()
        self.buy_once = reader.read_bool()

    def write(self, writer: Writer):
        writer.write_byte(self.slot)
        writer.write_short(self.item_type)
        writer.write_short(self.stack)
        writer.write_byte(self.prefix)
        writer.write_int(self.value)
        writer.write_bool(self.buy_once)
